/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DL3Y.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DL3Y *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DL3Y_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DL3Y));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DL3Y(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DL3Y_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DL3Y();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DL3Y::Heavy_WSTD_DL3Y(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_oAWrsaf7);
  numBytes += sLine_init(&sLine_SaNjLxrq);
  numBytes += sLine_init(&sLine_CuXIByKK);
  numBytes += sLine_init(&sLine_JAleIM1k);
  numBytes += sLine_init(&sLine_0PtToTex);
  numBytes += sBiquad_init(&sBiquad_s_T7bck5K6);
  numBytes += sLine_init(&sLine_c12qjFl0);
  numBytes += sLine_init(&sLine_sqAxfTuM);
  numBytes += sLine_init(&sLine_HA2HptCo);
  numBytes += sLine_init(&sLine_ivvDzFGK);
  numBytes += sBiquad_init(&sBiquad_s_58Wadtr3);
  numBytes += sLine_init(&sLine_u7CLUdjX);
  numBytes += sLine_init(&sLine_BKv0ZQ84);
  numBytes += sLine_init(&sLine_WIQAcIbv);
  numBytes += sLine_init(&sLine_f1DGJdvU);
  numBytes += sLine_init(&sLine_vJxh4Cvg);
  numBytes += sBiquad_init(&sBiquad_s_21P1qFYQ);
  numBytes += sLine_init(&sLine_g710SEAi);
  numBytes += sLine_init(&sLine_bcKpJuhl);
  numBytes += sLine_init(&sLine_gUT38zaz);
  numBytes += sLine_init(&sLine_JmRA0MNW);
  numBytes += sLine_init(&sLine_UbTnf1LI);
  numBytes += sBiquad_init(&sBiquad_s_j6RX23Dl);
  numBytes += sLine_init(&sLine_oQd2rxIY);
  numBytes += sLine_init(&sLine_XtxaQvlg);
  numBytes += sLine_init(&sLine_FPQC4mQQ);
  numBytes += sLine_init(&sLine_5NzbOYOl);
  numBytes += sBiquad_init(&sBiquad_s_8fQbPVnY);
  numBytes += sLine_init(&sLine_mpYBqQbF);
  numBytes += sLine_init(&sLine_nNMNxeFp);
  numBytes += sLine_init(&sLine_jkfFCd70);
  numBytes += sLine_init(&sLine_DQSIZ7Ji);
  numBytes += sLine_init(&sLine_Yp8UFEAS);
  numBytes += sBiquad_init(&sBiquad_s_45RQ3u4k);
  numBytes += sLine_init(&sLine_fPL1nTbV);
  numBytes += sTabread_init(&sTabread_YTAc1eGi, &hTable_2TJiAnQM, true);
  numBytes += sLine_init(&sLine_6Q15kY8v);
  numBytes += sLine_init(&sLine_kNqIEllm);
  numBytes += sTabread_init(&sTabread_FXx7x2fI, &hTable_g3z6Jf22, true);
  numBytes += sLine_init(&sLine_qC2PO2eF);
  numBytes += sRPole_init(&sRPole_yv82bcbO);
  numBytes += sDel1_init(&sDel1_gALBNs36);
  numBytes += sTabwrite_init(&sTabwrite_e3nhwujO, &hTable_2TJiAnQM);
  numBytes += sRPole_init(&sRPole_pZYhOkSJ);
  numBytes += sDel1_init(&sDel1_b0rrKSom);
  numBytes += sTabwrite_init(&sTabwrite_kSPc10lI, &hTable_g3z6Jf22);
  numBytes += sLine_init(&sLine_n4WfCNIw);
  numBytes += sLine_init(&sLine_Hrp3Pteq);
  numBytes += sRPole_init(&sRPole_ldwBviHm);
  numBytes += sEnv_init(&sEnv_R7KMdNr7, 1024, 512);
  numBytes += sRPole_init(&sRPole_HmumN3yJ);
  numBytes += sLine_init(&sLine_dF9FGcNU);
  numBytes += sLine_init(&sLine_I10cEbaR);
  numBytes += sRPole_init(&sRPole_0OvU1Wya);
  numBytes += sEnv_init(&sEnv_BPLru1Ws, 1024, 512);
  numBytes += sRPole_init(&sRPole_WOZV0hAS);
  numBytes += sLine_init(&sLine_S3bp2jJd);
  numBytes += sTabread_init(&sTabread_HEZUet5I, &hTable_l0IncrFz, true);
  numBytes += sLine_init(&sLine_o0zXKTjv);
  numBytes += sLine_init(&sLine_60cscanS);
  numBytes += sTabread_init(&sTabread_SSFbyvXA, &hTable_QNUaIDyf, true);
  numBytes += sLine_init(&sLine_8iunXTgk);
  numBytes += sRPole_init(&sRPole_mFLodRy0);
  numBytes += sDel1_init(&sDel1_7rAvAq81);
  numBytes += sTabwrite_init(&sTabwrite_ZOw8edq6, &hTable_l0IncrFz);
  numBytes += sRPole_init(&sRPole_tQfvWWqY);
  numBytes += sDel1_init(&sDel1_QJQaX2zJ);
  numBytes += sTabwrite_init(&sTabwrite_le5aNwMb, &hTable_QNUaIDyf);
  numBytes += sLine_init(&sLine_LAEdQWtq);
  numBytes += sLine_init(&sLine_xWgem0k7);
  numBytes += sRPole_init(&sRPole_TUHuLhvD);
  numBytes += sEnv_init(&sEnv_7C53T0Pd, 1024, 512);
  numBytes += sRPole_init(&sRPole_k7XoHDGI);
  numBytes += sLine_init(&sLine_7pOtSAQi);
  numBytes += sLine_init(&sLine_tDhPsPIX);
  numBytes += sRPole_init(&sRPole_l00A3EOI);
  numBytes += sEnv_init(&sEnv_DFJIEQRx, 1024, 512);
  numBytes += sRPole_init(&sRPole_fi4rshew);
  numBytes += sLine_init(&sLine_sjnrv9ru);
  numBytes += sTabread_init(&sTabread_14kgdxnh, &hTable_H0dtbbzM, true);
  numBytes += sLine_init(&sLine_3AjZ855b);
  numBytes += sLine_init(&sLine_ZWKg5aZO);
  numBytes += sTabread_init(&sTabread_dOrlPuKQ, &hTable_7IyuYJGc, true);
  numBytes += sLine_init(&sLine_KSjAeUBA);
  numBytes += sRPole_init(&sRPole_z2p1vX1N);
  numBytes += sDel1_init(&sDel1_pPwnCmUE);
  numBytes += sTabwrite_init(&sTabwrite_O636VV2I, &hTable_H0dtbbzM);
  numBytes += sRPole_init(&sRPole_xm2AYPaA);
  numBytes += sDel1_init(&sDel1_6pO0fgxC);
  numBytes += sTabwrite_init(&sTabwrite_No5W9kPu, &hTable_7IyuYJGc);
  numBytes += sLine_init(&sLine_P8N7HRta);
  numBytes += sLine_init(&sLine_Ajm2fVNm);
  numBytes += sRPole_init(&sRPole_3PWyyig8);
  numBytes += sEnv_init(&sEnv_Gm5Etzfd, 1024, 512);
  numBytes += sRPole_init(&sRPole_i4QSOT7t);
  numBytes += sLine_init(&sLine_zo6ZxP0q);
  numBytes += sLine_init(&sLine_IasK3k7S);
  numBytes += sRPole_init(&sRPole_yQqRs6qj);
  numBytes += sEnv_init(&sEnv_LcphiCwq, 1024, 512);
  numBytes += sRPole_init(&sRPole_W2TrxtEi);
  numBytes += cVar_init_f(&cVar_8AIbEzxt, 0.0f);
  numBytes += cVar_init_f(&cVar_vEJahI4V, 0.0f);
  numBytes += cVar_init_f(&cVar_2knd23K7, 0.0f);
  numBytes += cVar_init_f(&cVar_FRRCIK43, 0.0f);
  numBytes += cSlice_init(&cSlice_aDpXeEoN, 1, -1);
  numBytes += cVar_init_f(&cVar_cNPSSeq1, 1337.0f);
  numBytes += cVar_init_f(&cVar_1p8o5IXl, 0.0f);
  numBytes += cIf_init(&cIf_NRBfwdFf, false);
  numBytes += cIf_init(&cIf_ONNMk4On, false);
  numBytes += cBinop_init(&cBinop_6rOX5aQg, 0.0f); // __pow
  numBytes += cIf_init(&cIf_olMbVkcP, false);
  numBytes += cBinop_init(&cBinop_K53OcpNz, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_5IdiXeBf, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_efCroeju, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_D4JXkojW, 0.0f);
  numBytes += cIf_init(&cIf_cLh3zlm9, false);
  numBytes += cIf_init(&cIf_5kq7c1VU, false);
  numBytes += cBinop_init(&cBinop_H6r8jXWp, 0.0f); // __pow
  numBytes += cIf_init(&cIf_COWKPtwJ, false);
  numBytes += cBinop_init(&cBinop_cvZ4UhRi, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_hGA5rcYj, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_8qYrkBgq, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_IQGe4dU1, 0.0f);
  numBytes += cIf_init(&cIf_PNPVbds6, false);
  numBytes += cIf_init(&cIf_oOcKJQrw, false);
  numBytes += cBinop_init(&cBinop_FtpGF1Ss, 0.0f); // __pow
  numBytes += cIf_init(&cIf_vItnxxb5, false);
  numBytes += cBinop_init(&cBinop_z7c6YQtu, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_eolPkf3a, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_YCE336iN, -15.0f); // __eq
  numBytes += cIf_init(&cIf_ZwWsJI60, false);
  numBytes += cSlice_init(&cSlice_AjEApCPZ, 1, -1);
  numBytes += cVar_init_f(&cVar_ZIH5VoQY, 0.0f);
  numBytes += cSlice_init(&cSlice_EjiIhUpA, 1, -1);
  numBytes += cVar_init_f(&cVar_OqMqysVy, 0.0f);
  numBytes += cSlice_init(&cSlice_h4AHURpH, 1, -1);
  numBytes += cVar_init_f(&cVar_F8cbvIgH, 0.0f);
  numBytes += cSlice_init(&cSlice_RN5H0eqi, 1, -1);
  numBytes += cVar_init_f(&cVar_zWjsu0A7, 0.313f);
  numBytes += cBinop_init(&cBinop_WBmxKw2Z, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_LW9oVMMO, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_di4IyQ58, 0.0f);
  numBytes += cVar_init_f(&cVar_V74cagld, 1337.0f);
  numBytes += cVar_init_f(&cVar_nQDuLITl, 0.3f);
  numBytes += cBinop_init(&cBinop_Jsy28npv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ln3woWrn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_hevdNCbC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WzdctXoM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vmXq8p5N, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Qe3V4FwJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_msKbEaAY, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_MKyNpA6r, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_RvOEGnh4, 0.0f);
  numBytes += cVar_init_f(&cVar_SUR3GEK8, 1337.0f);
  numBytes += cVar_init_f(&cVar_qS9lxrsb, 0.313f);
  numBytes += cBinop_init(&cBinop_IYIFFUkb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_wNMvUoqL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_OytetkHo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7EygMUr9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ImmER6oC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_OUc6DMhd, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_OwzaUmoZ, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_mxmaOxTz, 0.0f);
  numBytes += cVar_init_f(&cVar_zPPHzmN4, 1037.0f);
  numBytes += cVar_init_f(&cVar_Ea2943m1, 0.4f);
  numBytes += cBinop_init(&cBinop_JLvllVCD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lrQUFgtw, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ln7fYe1V, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_k0xyHOD9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zx3IRNE8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_RWT1XW0O, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_28moRHHy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tCJ8XUM2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GNj2LvMJ, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_PmrINZl9, 1, -1);
  numBytes += cVar_init_f(&cVar_HFSnbzmu, 1337.0f);
  numBytes += cVar_init_f(&cVar_CZNMoKGu, 0.0f);
  numBytes += cIf_init(&cIf_d38YRVuu, false);
  numBytes += cIf_init(&cIf_BWxl6RDn, false);
  numBytes += cBinop_init(&cBinop_iXajQOIT, 0.0f); // __pow
  numBytes += cIf_init(&cIf_0bfluVlz, false);
  numBytes += cBinop_init(&cBinop_59Au4MRZ, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_AibsBG2i, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_xoKv3q6I, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_Jrt5pYDn, 0.0f);
  numBytes += cIf_init(&cIf_OYRq2ALw, false);
  numBytes += cIf_init(&cIf_pWoHAGV3, false);
  numBytes += cBinop_init(&cBinop_2Wcd4fnN, 0.0f); // __pow
  numBytes += cIf_init(&cIf_o66ERSgP, false);
  numBytes += cBinop_init(&cBinop_57VhYWye, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_qaOwSmsF, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_7jcKMWRf, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_epNyGda0, 0.0f);
  numBytes += cIf_init(&cIf_5cWCsixK, false);
  numBytes += cIf_init(&cIf_AZiJz5yj, false);
  numBytes += cBinop_init(&cBinop_Vsiy5Npu, 0.0f); // __pow
  numBytes += cIf_init(&cIf_EE4HmnkI, false);
  numBytes += cBinop_init(&cBinop_0OwmO8St, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_SQu6pKGt, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_LCv9s81p, -15.0f); // __eq
  numBytes += cIf_init(&cIf_tZhKbANh, false);
  numBytes += cSlice_init(&cSlice_TZ77hxEN, 1, -1);
  numBytes += cVar_init_f(&cVar_S52nkQ35, 0.0f);
  numBytes += cSlice_init(&cSlice_sAbi9MZ6, 1, -1);
  numBytes += cVar_init_f(&cVar_BRbGdHJ4, 0.0f);
  numBytes += cSlice_init(&cSlice_eVVCLV3y, 1, -1);
  numBytes += cVar_init_f(&cVar_VXMoJ0xC, 0.0f);
  numBytes += cSlice_init(&cSlice_njRFjJ5M, 1, -1);
  numBytes += cVar_init_f(&cVar_x67ET3YF, 0.313f);
  numBytes += cBinop_init(&cBinop_RpWuKXDJ, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_wxJK9Yqg, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_ekagkfq5, 0.0f);
  numBytes += cVar_init_f(&cVar_EBAXsYgY, 1337.0f);
  numBytes += cVar_init_f(&cVar_co1FloiR, 0.3f);
  numBytes += cBinop_init(&cBinop_rXxsQpn1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_CTA0gvK1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UTVuaMls, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jASeFPqP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_H1fA7WFT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Lesitg4n, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XOAJYDaS, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_rleJzxaQ, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_JnAi2EXW, 0.0f);
  numBytes += cVar_init_f(&cVar_wr6KGGeN, 1337.0f);
  numBytes += cVar_init_f(&cVar_FshHCpUl, 0.313f);
  numBytes += cBinop_init(&cBinop_zwkYmD3N, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jlEt08Ff, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QtL6n8r3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9E6f7olH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Ta0rLrbo, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_wb0C6g5O, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_ytDydfkh, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_SekYz6iy, 0.0f);
  numBytes += cVar_init_f(&cVar_14VmvNF3, 1037.0f);
  numBytes += cVar_init_f(&cVar_8RYASZS9, 0.4f);
  numBytes += cBinop_init(&cBinop_pcMt1H0v, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vVffNvLZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_nKzSQA8R, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_c5MHlenX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_BUYvBiVK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_BwmlDwH2, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_NWLA7g28, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OmqMZ123, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dhgRowel, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_H78fpCa7, 5705.6f);
  numBytes += cVar_init_f(&cVar_F6tEV1yv, 313.3f);
  numBytes += cBinop_init(&cBinop_9t8RsZtg, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_t8XiNxrE, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_WcZVJCxa, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_HIcib3vF, 0.0f);
  numBytes += cVar_init_f(&cVar_Z1bOiHrq, 0.0f);
  numBytes += cVar_init_f(&cVar_1QqZJ2dt, 0.0f);
  numBytes += cVar_init_f(&cVar_RMDuOn6A, 0.0f);
  numBytes += cVar_init_f(&cVar_01UEqjl1, 0.0f);
  numBytes += cVar_init_f(&cVar_JRRPP6HI, 0.0f);
  numBytes += cVar_init_f(&cVar_VV6qcL92, 0.0f);
  numBytes += cVar_init_f(&cVar_4FP6U4iV, 0.0f);
  numBytes += cVar_init_f(&cVar_kkHPw3JI, 0.0f);
  numBytes += cVar_init_f(&cVar_ajVwMvq4, 0.0f);
  numBytes += cVar_init_f(&cVar_AtrdkoUE, 0.0f);
  numBytes += cVar_init_f(&cVar_gDNwohAn, 0.0f);
  numBytes += cSlice_init(&cSlice_bskCx97a, 1, -1);
  numBytes += cVar_init_f(&cVar_CYGfkcI6, 0.5f);
  numBytes += cSlice_init(&cSlice_4mtfwDNt, 1, -1);
  numBytes += cVar_init_f(&cVar_Od6YCvBB, 0.2f);
  numBytes += cSlice_init(&cSlice_bBGn3tfj, 1, -1);
  numBytes += cVar_init_f(&cVar_NbUU5fxS, 500.0f);
  numBytes += sVarf_init(&sVarf_C4puBAOZ, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_X8IxcfBq, 600.0f);
  numBytes += cBinop_init(&cBinop_XEzTmUOp, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_GVUhSYk3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_47fjI4x8, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_SiMQL5Q8, 600.0f);
  numBytes += cBinop_init(&cBinop_Z3JieaBf, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_BddhWH9f, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_MYQbQPF5, 4000.0f);
  numBytes += cBinop_init(&cBinop_qMxf9MM7, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_kxbOVXOL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SrSRaCdO, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_XvztEAth, 4000.0f);
  numBytes += cBinop_init(&cBinop_ueOZflAA, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_EXVAPhov, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hDJ2Rwln, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_JrPOY8Iq, false);
  numBytes += cBinop_init(&cBinop_eMdLygJs, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_R75NEsvO, 20.0f);
  numBytes += cBinop_init(&cBinop_x5hupr4N, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_w8sWCTUd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_x7vQuWH9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7JAhamID, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_BakUPGMx, false);
  numBytes += cBinop_init(&cBinop_P2ytd1vG, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_qINp6PyF, 20.0f);
  numBytes += cBinop_init(&cBinop_Vgv6Z6Mv, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_vgDHB84c, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4EdKcnoH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LqnSAJ94, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_DXQUm44S, 1, -1);
  numBytes += cVar_init_f(&cVar_lYv5QyXa, 0.25f);
  numBytes += cDelay_init(this, &cDelay_tJUiNGKp, 0.0f);
  numBytes += cDelay_init(this, &cDelay_u6lR5uww, 0.0f);
  numBytes += hTable_init(&hTable_2TJiAnQM, 256);
  numBytes += cTabhead_init(&cTabhead_4x4kdZJU, &hTable_2TJiAnQM);
  numBytes += cVar_init_s(&cVar_PI4U6Mmn, "del-1349-delayL");
  numBytes += cDelay_init(this, &cDelay_Lc0ZQWPK, 0.0f);
  numBytes += cDelay_init(this, &cDelay_2i0JsUtX, 0.0f);
  numBytes += cBinop_init(&cBinop_mT4STFHE, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_pW9EdCht, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_6lSEmWdw, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_XSGHRIrl, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_hYDskwtN, 0.0f);
  numBytes += cDelay_init(this, &cDelay_0uOi5H0L, 0.0f);
  numBytes += hTable_init(&hTable_g3z6Jf22, 256);
  numBytes += cTabhead_init(&cTabhead_5u8fXqna, &hTable_g3z6Jf22);
  numBytes += cVar_init_s(&cVar_dwJzxV2b, "del-1349-delayR");
  numBytes += cDelay_init(this, &cDelay_rLK3plVx, 0.0f);
  numBytes += cDelay_init(this, &cDelay_IQ6JvE7m, 0.0f);
  numBytes += cBinop_init(&cBinop_qrMbILk8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_pEfbpW5i, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_x3k326Mk, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_4IcQqkIa, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_MBCoUBC6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Df0ol2om, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_F1tZn93S, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_a0YUElSA, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_CNfZgmT5, 1, -1);
  numBytes += cVar_init_f(&cVar_QqZgQQo0, 0.5f);
  numBytes += cSlice_init(&cSlice_5bzc19UV, 1, -1);
  numBytes += cVar_init_f(&cVar_kyzIOww6, 0.2f);
  numBytes += cSlice_init(&cSlice_JIlumW5t, 1, -1);
  numBytes += cVar_init_f(&cVar_emYzPpJ2, 500.0f);
  numBytes += sVarf_init(&sVarf_LOlQSmis, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_xUXetBxK, 600.0f);
  numBytes += cBinop_init(&cBinop_IH2JIhuP, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_mokwH5ld, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5c6VN4ks, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_oyIcYOO3, 600.0f);
  numBytes += cBinop_init(&cBinop_grf1JvHW, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_0oHZGur4, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_MdUAbMMH, 4000.0f);
  numBytes += cBinop_init(&cBinop_DxBMuHjg, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_9PHF0dZB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KzbXvgt2, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_to9gHNOr, 4000.0f);
  numBytes += cBinop_init(&cBinop_GTFlITUC, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_N7UIBDem, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LK24UNKO, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_qiY788Or, false);
  numBytes += cBinop_init(&cBinop_pxl1r00e, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_uGoxyvne, 20.0f);
  numBytes += cBinop_init(&cBinop_Fxyvbjya, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_uQztaIh0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_V3kRjJzs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5S5vOXMH, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_aQN6Rz0x, false);
  numBytes += cBinop_init(&cBinop_VMAXN0P1, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_nxrxgwKC, 20.0f);
  numBytes += cBinop_init(&cBinop_OnWefO3P, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_O0z3mHw6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RI08X2CC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_x1DmdgrR, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_8ojyUrPu, 1, -1);
  numBytes += cVar_init_f(&cVar_IovWFZpH, 0.25f);
  numBytes += cDelay_init(this, &cDelay_q550ckdZ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_1EbdII70, 0.0f);
  numBytes += hTable_init(&hTable_l0IncrFz, 256);
  numBytes += cTabhead_init(&cTabhead_OIHZAbFg, &hTable_l0IncrFz);
  numBytes += cVar_init_s(&cVar_014zaDta, "del-1428-delayL");
  numBytes += cDelay_init(this, &cDelay_m6jKyC4p, 0.0f);
  numBytes += cDelay_init(this, &cDelay_3tiRgNAW, 0.0f);
  numBytes += cBinop_init(&cBinop_MvexPnO7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_K4tjGFvd, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_XsBiMf7l, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_YxLkTspv, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_ePmoaHbq, 0.0f);
  numBytes += cDelay_init(this, &cDelay_hbPEdna8, 0.0f);
  numBytes += hTable_init(&hTable_QNUaIDyf, 256);
  numBytes += cTabhead_init(&cTabhead_jMesxc8B, &hTable_QNUaIDyf);
  numBytes += cVar_init_s(&cVar_WRJ2OwTY, "del-1428-delayR");
  numBytes += cDelay_init(this, &cDelay_zVsjffV0, 0.0f);
  numBytes += cDelay_init(this, &cDelay_USpfw6Pp, 0.0f);
  numBytes += cBinop_init(&cBinop_1W7dH990, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_eKjZ7Hq6, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_iBkrQsoe, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_Gi16lz0U, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_n3seJudm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MxyQS9ed, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QYTkdLuL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UNKHeMm7, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_Y4dPGUJj, 1, -1);
  numBytes += cVar_init_f(&cVar_jBOqt7RQ, 0.5f);
  numBytes += cSlice_init(&cSlice_hmBfsXXD, 1, -1);
  numBytes += cVar_init_f(&cVar_rlxLNri8, 0.2f);
  numBytes += cSlice_init(&cSlice_HucTGjmQ, 1, -1);
  numBytes += cVar_init_f(&cVar_2qQrIAiR, 500.0f);
  numBytes += sVarf_init(&sVarf_CaPtF90q, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_jN81pU6p, 600.0f);
  numBytes += cBinop_init(&cBinop_ys3c3J3X, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_ItvRIWgD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2V1QJf8D, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_AbjLWBiB, 600.0f);
  numBytes += cBinop_init(&cBinop_OLkEK77x, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_XWmMfFw8, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_JzFgnREq, 4000.0f);
  numBytes += cBinop_init(&cBinop_nDiR83wp, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_ea4D5TlJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cXKK7fEd, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_5fzM89CI, 4000.0f);
  numBytes += cBinop_init(&cBinop_z697gQG0, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_ygmG6B2l, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tHwzBFle, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_PTjcZFqb, false);
  numBytes += cBinop_init(&cBinop_6ba0fGE7, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_bs9lxL49, 20.0f);
  numBytes += cBinop_init(&cBinop_SGIiRRvL, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_D08FwTfS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iKvg9tEB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2FELjDFx, 0.0f, 0.0f, false);
  numBytes += cIf_init(&cIf_PXkCSibE, false);
  numBytes += cBinop_init(&cBinop_Kks8ijIU, 0.0f); // __pow
  numBytes += cVar_init_f(&cVar_qYNayVPB, 20.0f);
  numBytes += cBinop_init(&cBinop_XtnGdl5o, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_09yBpt3P, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9YTKvYQ5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HpeargDJ, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_jHFtejUC, 1, -1);
  numBytes += cVar_init_f(&cVar_HcMVUmml, 0.25f);
  numBytes += cDelay_init(this, &cDelay_zB4l4ZFN, 0.0f);
  numBytes += cDelay_init(this, &cDelay_UakUDZC6, 0.0f);
  numBytes += hTable_init(&hTable_H0dtbbzM, 256);
  numBytes += cTabhead_init(&cTabhead_OnklvKOT, &hTable_H0dtbbzM);
  numBytes += cVar_init_s(&cVar_oYKO7Gfk, "del-1507-delayL");
  numBytes += cDelay_init(this, &cDelay_MWOwftR3, 0.0f);
  numBytes += cDelay_init(this, &cDelay_oLdt0x4U, 0.0f);
  numBytes += cBinop_init(&cBinop_8nkUUida, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GCx5w7Db, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_ViCJyBvh, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_HpJ8NsvE, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_PPyLO5LO, 0.0f);
  numBytes += cDelay_init(this, &cDelay_eyGQl0fW, 0.0f);
  numBytes += hTable_init(&hTable_7IyuYJGc, 256);
  numBytes += cTabhead_init(&cTabhead_NgciWd3p, &hTable_7IyuYJGc);
  numBytes += cVar_init_s(&cVar_aPZqDUFe, "del-1507-delayR");
  numBytes += cDelay_init(this, &cDelay_6ixuekj4, 0.0f);
  numBytes += cDelay_init(this, &cDelay_2Ktd88EV, 0.0f);
  numBytes += cBinop_init(&cBinop_cBaBZXTR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_liegG1R5, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_Pc6FFFMw, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_oH3og9jz, 0.0f); // __sub
  numBytes += sVarf_init(&sVarf_R5DxSDrV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OQavpGKp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_JHCci2hY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SWogqwKA, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_VvcSrGlx, 1.0f);
  numBytes += cIf_init(&cIf_K61ULp54, false);
  numBytes += cIf_init(&cIf_g7Cymyuj, false);
  numBytes += cVar_init_f(&cVar_wBptCiL9, 0.0f);
  numBytes += cVar_init_f(&cVar_MAYqDEZk, 0.0f);
  numBytes += cVar_init_f(&cVar_2UWh6rW1, 1.0f);
  numBytes += cIf_init(&cIf_yQGhBQeR, false);
  numBytes += cIf_init(&cIf_5hj4MkKl, false);
  numBytes += cVar_init_f(&cVar_bDEEkYjS, 0.0f);
  numBytes += cVar_init_f(&cVar_g9M4JmQL, 0.0f);
  numBytes += cVar_init_f(&cVar_kajGFQeT, 1.0f);
  numBytes += cIf_init(&cIf_f2np9MJg, false);
  numBytes += cIf_init(&cIf_dhn8p6XR, false);
  numBytes += cVar_init_f(&cVar_zunxaUUd, 0.0f);
  numBytes += cVar_init_f(&cVar_T36cu6At, 0.0f);
  numBytes += cVar_init_f(&cVar_S174Ast0, 60000.0f);
  numBytes += cVar_init_f(&cVar_QkDdz1zO, 500.0f);
  numBytes += cSlice_init(&cSlice_siliQPjb, 1, -1);
  numBytes += cSlice_init(&cSlice_75sbklFL, 1, -1);
  numBytes += cVar_init_f(&cVar_uyAVZCm9, 0.0f);
  numBytes += cIf_init(&cIf_lxFA50t2, false);
  numBytes += cBinop_init(&cBinop_2RTJVtRg, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_YTznyMpd, 120.0f);
  numBytes += cBinop_init(&cBinop_KBbYgMq3, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_jIU5sHgG, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_Cmf7BGVW, 60000.0f);
  numBytes += cVar_init_f(&cVar_H77wVM5Y, 500.0f);
  numBytes += cSlice_init(&cSlice_Yl8aZ9sI, 1, -1);
  numBytes += cSlice_init(&cSlice_zVEhcqNk, 1, -1);
  numBytes += cVar_init_f(&cVar_GR9Lnaa7, 0.0f);
  numBytes += cIf_init(&cIf_fhOYslsN, false);
  numBytes += cBinop_init(&cBinop_7iZT1P2a, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_0x7IhzAj, 120.0f);
  numBytes += cBinop_init(&cBinop_bd0dPcB6, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_HbFSvobf, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_DxR2qksN, 60000.0f);
  numBytes += cVar_init_f(&cVar_hUXH3ocq, 500.0f);
  numBytes += cSlice_init(&cSlice_M0MegyC4, 1, -1);
  numBytes += cSlice_init(&cSlice_faX10WYN, 1, -1);
  numBytes += cVar_init_f(&cVar_duYsdInu, 0.0f);
  numBytes += cIf_init(&cIf_Z3riFqS3, false);
  numBytes += cBinop_init(&cBinop_xkeSvq1t, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_dm86fs1f, 120.0f);
  numBytes += cBinop_init(&cBinop_uWwJ6KeI, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_dMMJVfZC, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_eSrzHhFT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jsvWv8s5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZvmOlluh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5CisSy1j, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GS0GaIf5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nDteYBCD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YazP3TGe, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RP7zGMtz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PZEapFMB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6GotqVeQ, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DL3Y::~Heavy_WSTD_DL3Y() {
  sEnv_free(&sEnv_R7KMdNr7);
  sEnv_free(&sEnv_BPLru1Ws);
  sEnv_free(&sEnv_7C53T0Pd);
  sEnv_free(&sEnv_DFJIEQRx);
  sEnv_free(&sEnv_Gm5Etzfd);
  sEnv_free(&sEnv_LcphiCwq);
  hTable_free(&hTable_2TJiAnQM);
  hTable_free(&hTable_g3z6Jf22);
  hTable_free(&hTable_l0IncrFz);
  hTable_free(&hTable_QNUaIDyf);
  hTable_free(&hTable_H0dtbbzM);
  hTable_free(&hTable_7IyuYJGc);
}

HvTable *Heavy_WSTD_DL3Y::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x29B74AF: return &hTable_2TJiAnQM; // del-1349-delayL
    case 0x19A00729: return &hTable_g3z6Jf22; // del-1349-delayR
    case 0x584C8281: return &hTable_l0IncrFz; // del-1428-delayL
    case 0x54BF59F6: return &hTable_QNUaIDyf; // del-1428-delayR
    case 0xBCE693A: return &hTable_H0dtbbzM; // del-1507-delayL
    case 0x95A380B3: return &hTable_7IyuYJGc; // del-1507-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DL3Y::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wL8BaQbS_sendMessage);
      break;
    }
    case 0xBB584857: { // High_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pVzlOulz_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TFHE9KiO_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3SpA0LUG_sendMessage);
      break;
    }
    case 0xDD62B09F: { // High_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZEPemisj_sendMessage);
      break;
    }
    case 0xABB0CBCF: { // High_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3wpYGozh_sendMessage);
      break;
    }
    case 0xAE942A2: { // High_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_paBvK1km_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kwz1v12X_sendMessage);
      break;
    }
    case 0xA2D68920: { // Low_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PgIIneDX_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WWFjglF9_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0FSlm4u1_sendMessage);
      break;
    }
    case 0xFFFEE96: { // Low_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WZy6S8K5_sendMessage);
      break;
    }
    case 0xA3BD8A20: { // Low_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5XcrIbSf_sendMessage);
      break;
    }
    case 0x67F58CFB: { // Low_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JKMWZMRI_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aBmncDwJ_sendMessage);
      break;
    }
    case 0x59607D3: { // Mid_Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_R6oqS1PF_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jFVMZOfU_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RYifdDiL_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5vIVKI28_sendMessage);
      break;
    }
    case 0x96E19510: { // Mid_Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QckBwmuj_sendMessage);
      break;
    }
    case 0xE1DB1774: { // Mid_Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0re5oY55_sendMessage);
      break;
    }
    case 0xDB67B94E: { // Mid_TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uxZlzIFu_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GpbsIBH0_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4nf1Da6a_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Cdh4rCMb_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RGGFGxrM_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2oSRUFmJ_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_noE7Wf2R_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lCMKuObd_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_J8T1cKfK_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hbsYMy42_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_q0PRY8wv_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TkoW1RA5_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AW26Cqif_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_187foEsP_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_o8Frug87_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YHgfewaV_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5HpT3tlU_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WBAhwWI8_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lcHXCE7c_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wEgMAHNe_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HpxgKr8Y_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lcrQtmg4_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YvFhO41Y_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Q4GA74OE_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sJoBkXIP_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zBfj5idJ_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5b791AMa_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_M15RNXyW_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NTIern86_sendMessage);
      break;
    }
    case 0x9FC1C9E5: { // 1349-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7mxGoF1X_sendMessage);
      break;
    }
    case 0x5D7BD4E9: { // 1349-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JzO02vEi_sendMessage);
      break;
    }
    case 0x371A347A: { // 1349-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LxBaMFtc_sendMessage);
      break;
    }
    case 0x810E74BC: { // 1349-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OOQXJ5G3_sendMessage);
      break;
    }
    case 0xCC56B3CF: { // 1428-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4EGD97Mr_sendMessage);
      break;
    }
    case 0x499A953B: { // 1428-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_r08WcwYK_sendMessage);
      break;
    }
    case 0xE0E7225B: { // 1428-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8W4hhjx5_sendMessage);
      break;
    }
    case 0xE6486F5F: { // 1428-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_duyFzwf1_sendMessage);
      break;
    }
    case 0xF65E8330: { // 1507-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kGJXrN4H_sendMessage);
      break;
    }
    case 0x3B8B5FB8: { // 1507-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nleWyDXn_sendMessage);
      break;
    }
    case 0xE5F26E0D: { // 1507-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fWf1QHfQ_sendMessage);
      break;
    }
    case 0xFDAB8735: { // 1507-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AkCHELWB_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gs0vypzf_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FXXVVSPv_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DL3Y::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Cross";
        info->hash = 0xBB584857;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Sync";
        info->hash = 0xDD62B09F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "High_Time";
        info->hash = 0xABB0CBCF;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 6: {
        info->name = "High_TimeSync";
        info->hash = 0xAE942A2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 7: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low_Cross";
        info->hash = 0xA2D68920;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 9: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 10: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 11: {
        info->name = "Low_Sync";
        info->hash = 0xFFFEE96;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Time";
        info->hash = 0xA3BD8A20;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 13: {
        info->name = "Low_TimeSync";
        info->hash = 0x67F58CFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      case 14: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Cross";
        info->hash = 0x59607D3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 16: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Sync";
        info->hash = 0x96E19510;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Time";
        info->hash = 0xE1DB1774;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 21: {
        info->name = "Mid_TimeSync";
        info->hash = 0xDB67B94E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 22;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DL3Y::cVar_8AIbEzxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Iwkqe8HD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_vEJahI4V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mVSp9xwA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_2knd23K7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vyTv0lW0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_FRRCIK43_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4m4grr14_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BwPIi1tR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4xSxoZpl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5gUfuh4w_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_XKh3mp5G_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_aDpXeEoN, 0, m, &cSlice_aDpXeEoN_sendMessage);
      break;
    }
    default: {
      cSwitchcase_OnC21EDG_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_aDpXeEoN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_quWVFjRg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_quWVFjRg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_cNPSSeq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_quWVFjRg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_quWVFjRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Cdh4rCMb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_1p8o5IXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_46dD6cnW_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_NRBfwdFf, 0, m, &cIf_NRBfwdFf_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_NRBfwdFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ulgnT3Gk_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_ONNMk4On_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_J3OIQoQM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_onspwIDs_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_DYuRz1yd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6rOX5aQg, HV_BINOP_POW, 0, m, &cBinop_6rOX5aQg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6rOX5aQg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_olMbVkcP, 0, m, &cIf_olMbVkcP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mLhgn0Wd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_xg1T6CxR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_KnimH6HP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ONNMk4On, 0, m, &cIf_ONNMk4On_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xJWhsjjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_RldA1FWf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_RldA1FWf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ONNMk4On, 1, m, &cIf_ONNMk4On_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_onspwIDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_mLhgn0Wd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_J3OIQoQM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_olMbVkcP, 0, m, &cIf_olMbVkcP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xg1T6CxR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6rOX5aQg, HV_BINOP_POW, 1, m, &cBinop_6rOX5aQg_sendMessage);
  cMsg_DYuRz1yd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_olMbVkcP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_28moRHHy, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_46dD6cnW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NRBfwdFf, 1, m, &cIf_NRBfwdFf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ulgnT3Gk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5IdiXeBf, HV_BINOP_GREATER_THAN, 1, m, &cBinop_5IdiXeBf_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_efCroeju, HV_BINOP_EQ, 1, m, &cBinop_efCroeju_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_sR7f2KjO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_K53OcpNz, HV_BINOP_ADD, 0, m, &cBinop_K53OcpNz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_K53OcpNz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xJWhsjjN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KnimH6HP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5IdiXeBf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_olMbVkcP, 1, m, &cIf_olMbVkcP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_efCroeju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TKQbMhyY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_TKQbMhyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_28moRHHy, m);
}

void Heavy_WSTD_DL3Y::cCast_k593SX1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K53OcpNz, HV_BINOP_ADD, 1, m, &cBinop_K53OcpNz_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5IdiXeBf, HV_BINOP_GREATER_THAN, 0, m, &cBinop_5IdiXeBf_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_efCroeju, HV_BINOP_EQ, 0, m, &cBinop_efCroeju_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rQqAXxpe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1p8o5IXl, 0, m, &cVar_1p8o5IXl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_h9WpkLyb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sR7f2KjO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_D4JXkojW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5Nv5mGDT_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_cLh3zlm9, 0, m, &cIf_cLh3zlm9_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_cLh3zlm9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_iWe6C6i9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_5kq7c1VU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_WFPKyK4e_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_JtYqEROc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_N3bnAm2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_H6r8jXWp, HV_BINOP_POW, 0, m, &cBinop_H6r8jXWp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_H6r8jXWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_COWKPtwJ, 0, m, &cIf_COWKPtwJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rJrmONbU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_30BSF1t0_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_A2VJ36pm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_OsGTp6iN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NvpNq86C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5kq7c1VU, 0, m, &cIf_5kq7c1VU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OsGTp6iN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5kq7c1VU, 1, m, &cIf_5kq7c1VU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JtYqEROc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_rJrmONbU_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_WFPKyK4e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_COWKPtwJ, 0, m, &cIf_COWKPtwJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_30BSF1t0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H6r8jXWp, HV_BINOP_POW, 1, m, &cBinop_H6r8jXWp_sendMessage);
  cMsg_N3bnAm2L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_COWKPtwJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_r2KPqNoG_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hUwwYM9q_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_BthAkdJd_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_5Nv5mGDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cLh3zlm9, 1, m, &cIf_cLh3zlm9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iWe6C6i9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hGA5rcYj, HV_BINOP_GREATER_THAN, 1, m, &cBinop_hGA5rcYj_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8qYrkBgq, HV_BINOP_EQ, 1, m, &cBinop_8qYrkBgq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_AVqbCWeJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cvZ4UhRi, HV_BINOP_ADD, 0, m, &cBinop_cvZ4UhRi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cvZ4UhRi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_A2VJ36pm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NvpNq86C_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hGA5rcYj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_COWKPtwJ, 1, m, &cIf_COWKPtwJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8qYrkBgq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YkgUoIkK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_YkgUoIkK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_r2KPqNoG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hUwwYM9q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_BthAkdJd_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_97evy8FD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_D4JXkojW, 0, m, &cVar_D4JXkojW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yZ89cllc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AVqbCWeJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_RyGPrxOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cvZ4UhRi, HV_BINOP_ADD, 1, m, &cBinop_cvZ4UhRi_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_hGA5rcYj, HV_BINOP_GREATER_THAN, 0, m, &cBinop_hGA5rcYj_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8qYrkBgq, HV_BINOP_EQ, 0, m, &cBinop_8qYrkBgq_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_IQGe4dU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_kVpZeQ8N_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_PNPVbds6, 0, m, &cIf_PNPVbds6_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_PNPVbds6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_QgYsYUI9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_oOcKJQrw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_73q2BXFP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_AnagswmO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_0Hd0f3hK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_FtpGF1Ss, HV_BINOP_POW, 0, m, &cBinop_FtpGF1Ss_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FtpGF1Ss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vItnxxb5, 0, m, &cIf_vItnxxb5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HhjJof8T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_fafyN4cg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wPindMHy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_iep7E129_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3rDA08uV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oOcKJQrw, 0, m, &cIf_oOcKJQrw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iep7E129_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oOcKJQrw, 1, m, &cIf_oOcKJQrw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AnagswmO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_HhjJof8T_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_73q2BXFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_vItnxxb5, 0, m, &cIf_vItnxxb5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_fafyN4cg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FtpGF1Ss, HV_BINOP_POW, 1, m, &cBinop_FtpGF1Ss_sendMessage);
  cMsg_0Hd0f3hK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_vItnxxb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_GNj2LvMJ, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_kVpZeQ8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PNPVbds6, 1, m, &cIf_PNPVbds6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QgYsYUI9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eolPkf3a, HV_BINOP_GREATER_THAN, 1, m, &cBinop_eolPkf3a_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YCE336iN, HV_BINOP_EQ, 1, m, &cBinop_YCE336iN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Am9ypFAg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_z7c6YQtu, HV_BINOP_ADD, 0, m, &cBinop_z7c6YQtu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_z7c6YQtu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wPindMHy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3rDA08uV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eolPkf3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vItnxxb5, 1, m, &cIf_vItnxxb5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YCE336iN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nhwWs28a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_nhwWs28a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_GNj2LvMJ, m);
}

void Heavy_WSTD_DL3Y::cCast_WECfqkKA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IQGe4dU1, 0, m, &cVar_IQGe4dU1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Eu9rbmXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Am9ypFAg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_lIssrBgM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z7c6YQtu, HV_BINOP_ADD, 1, m, &cBinop_z7c6YQtu_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_eolPkf3a, HV_BINOP_GREATER_THAN, 0, m, &cBinop_eolPkf3a_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YCE336iN, HV_BINOP_EQ, 0, m, &cBinop_YCE336iN_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_ZwWsJI60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_tCJ8XUM2, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_jSYWnAMy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_AjEApCPZ, 0, m, &cSlice_AjEApCPZ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_jKk8OK7X_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_AjEApCPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ooa6HDev_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ooa6HDev_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_ZIH5VoQY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ooa6HDev_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_ooa6HDev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GpbsIBH0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_jKk8OK7X_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_EjiIhUpA, 0, m, &cSlice_EjiIhUpA_sendMessage);
      break;
    }
    default: {
      cSwitchcase_XKh3mp5G_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_EjiIhUpA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ubPCrVdW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ubPCrVdW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_OqMqysVy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ubPCrVdW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_ubPCrVdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2oSRUFmJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_OnC21EDG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_h4AHURpH, 0, m, &cSlice_h4AHURpH_sendMessage);
      break;
    }
    default: {
      cSwitchcase_FFEE30kW_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_h4AHURpH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_EFzSnpqJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_EFzSnpqJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_F8cbvIgH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EFzSnpqJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_EFzSnpqJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4nf1Da6a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_FFEE30kW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_RN5H0eqi, 0, m, &cSlice_RN5H0eqi_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_RN5H0eqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0Pnh9wLh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0Pnh9wLh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_zWjsu0A7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0Pnh9wLh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_0Pnh9wLh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RGGFGxrM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_4Qvadc7Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oAWrsaf7, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_BvBxSov5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SaNjLxrq, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_hrvu6mJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CuXIByKK, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_uZU1kSbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JAleIM1k, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_3IHgZSOY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0PtToTex, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_hg3yNHGq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_U6t5aVjQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_U6t5aVjQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WBmxKw2Z, HV_BINOP_DIVIDE, 1, m, &cBinop_WBmxKw2Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8800GWX0_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_kAlcj2Fj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_GU66zgsy_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_v3Kgp1hB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_kAlcj2Fj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GU66zgsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WBmxKw2Z, HV_BINOP_DIVIDE, 0, m, &cBinop_WBmxKw2Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8800GWX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v3Kgp1hB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_WBmxKw2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LW9oVMMO, HV_BINOP_MULTIPLY, 1, m, &cBinop_LW9oVMMO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LW9oVMMO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yiEVVuMK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lV3II6O7_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_BKzQ5FC9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4yHnfVWQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_WhEsyF75_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gjFigq3h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Ofyryj7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_O3lpMzEO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_O3lpMzEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LW9oVMMO, HV_BINOP_MULTIPLY, 0, m, &cBinop_LW9oVMMO_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dSpdLL4w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_QUOvZbac_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_QUOvZbac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9fcvTc5m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_A6bktJCt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_di4IyQ58, 1, m, &cVar_di4IyQ58_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_di4IyQ58_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wUaKWBnw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_qC6o5ENQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ln3woWrn, HV_BINOP_MULTIPLY, 1, m, &cBinop_ln3woWrn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZVmChAqJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_qC6o5ENQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_e4wB61iG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_1xFN04ZQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1xFN04ZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hevdNCbC, HV_BINOP_MULTIPLY, 1, m, &cBinop_hevdNCbC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZwxKJoY3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WzdctXoM, HV_BINOP_MULTIPLY, 1, m, &cBinop_WzdctXoM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2rPvMhTH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ZwxKJoY3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_b6GDTicd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vmXq8p5N, HV_BINOP_MULTIPLY, 1, m, &cBinop_vmXq8p5N_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_O5sjIhrE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_z7RMnm2C_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_z7RMnm2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qe3V4FwJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_Qe3V4FwJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_V74cagld_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BzIHIuXe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_Ofyryj7d_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h4ivubR1_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_nQDuLITl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_dSpdLL4w_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_lV3II6O7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_WhEsyF75_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yiEVVuMK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_BKzQ5FC9_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_4yHnfVWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_J8T1cKfK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_gjFigq3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lCMKuObd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_OrpgtKin_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_noE7Wf2R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_9fcvTc5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_lDKp40sT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lDKp40sT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jsy28npv, HV_BINOP_MULTIPLY, 1, m, &cBinop_Jsy28npv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Jsy28npv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Xwp2rCAJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Xwp2rCAJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OrpgtKin_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_wUaKWBnw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_WAIU5P1I_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WAIU5P1I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qXCF6ZKZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_osPWrcxl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C8UMl1ef_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v28G5sOq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_U7sSL05w_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O01PC2Hf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ln3woWrn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4Qvadc7Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_hevdNCbC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BvBxSov5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_WzdctXoM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hrvu6mJT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_vmXq8p5N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uZU1kSbe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Qe3V4FwJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3IHgZSOY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_q4h3aG2D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_V74cagld, 0, m, &cVar_V74cagld_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZO0EX7I2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nQDuLITl, 1, m, &cVar_nQDuLITl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_U7sSL05w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hevdNCbC, HV_BINOP_MULTIPLY, 0, m, &cBinop_hevdNCbC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_osPWrcxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qe3V4FwJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_Qe3V4FwJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_v28G5sOq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WzdctXoM, HV_BINOP_MULTIPLY, 0, m, &cBinop_WzdctXoM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qXCF6ZKZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_O01PC2Hf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ln3woWrn, HV_BINOP_MULTIPLY, 0, m, &cBinop_ln3woWrn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_C8UMl1ef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vmXq8p5N, HV_BINOP_MULTIPLY, 0, m, &cBinop_vmXq8p5N_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_BzIHIuXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nQDuLITl, 0, m, &cVar_nQDuLITl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_h4ivubR1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_di4IyQ58, 0, m, &cVar_di4IyQ58_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_D5UKI3H0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_c12qjFl0, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_HZVu3BlT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sqAxfTuM, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_DLmLBTlx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HA2HptCo, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_tiJz4s6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ivvDzFGK, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_mF68kLsD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ERI3v22i_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ERI3v22i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_msKbEaAY, HV_BINOP_DIVIDE, 1, m, &cBinop_msKbEaAY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6L070waL_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_MuTfSAHW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_2zWMZUER_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zMtXVjx7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_MuTfSAHW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2zWMZUER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_msKbEaAY, HV_BINOP_DIVIDE, 0, m, &cBinop_msKbEaAY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_6L070waL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zMtXVjx7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_msKbEaAY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MKyNpA6r, HV_BINOP_MULTIPLY, 1, m, &cBinop_MKyNpA6r_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MKyNpA6r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rx7b2Zy4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rb4VE90z_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_HSgZW7iN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qpO08F3q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_QpwoQP79_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vVyELjgg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_mxyconNb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_GHMPX9qS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GHMPX9qS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MKyNpA6r, HV_BINOP_MULTIPLY, 0, m, &cBinop_MKyNpA6r_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BZNF1IMp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_IYQaj0Oy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IYQaj0Oy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xfF4ZKSQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_5EeIIud4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OytetkHo, HV_BINOP_MULTIPLY, 1, m, &cBinop_OytetkHo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2MscW6fR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RvOEGnh4, 1, m, &cVar_RvOEGnh4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TecFGHO6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7EygMUr9, HV_BINOP_MULTIPLY, 1, m, &cBinop_7EygMUr9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RlUyycl0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_A7CpRPDs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_A7CpRPDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ImmER6oC, HV_BINOP_MULTIPLY, 1, m, &cBinop_ImmER6oC_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_RvOEGnh4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UVN8FIdu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_SUR3GEK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_alrnf56T_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_mxyconNb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_90nMPXqF_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_qS9lxrsb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_BZNF1IMp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rb4VE90z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_QpwoQP79_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rx7b2Zy4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_HSgZW7iN_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_qpO08F3q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TkoW1RA5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_vVyELjgg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_q0PRY8wv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_LoC3hbYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hbsYMy42_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_xfF4ZKSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_5uWdEnlz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5uWdEnlz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IYIFFUkb, HV_BINOP_MULTIPLY, 1, m, &cBinop_IYIFFUkb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IYIFFUkb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_FJ6Z25JV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FJ6Z25JV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LoC3hbYt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_UVN8FIdu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_abiVk0Qw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_abiVk0Qw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TL0bF63p_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fSxFmDQa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kyR6Uf9Y_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_p0mWooV2_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wNMvUoqL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D5UKI3H0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_OytetkHo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HZVu3BlT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_7EygMUr9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DLmLBTlx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ImmER6oC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tiJz4s6K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_9BeMtM1i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SUR3GEK8, 0, m, &cVar_SUR3GEK8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_P3a1VwnS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qS9lxrsb, 1, m, &cVar_qS9lxrsb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_90nMPXqF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RvOEGnh4, 0, m, &cVar_RvOEGnh4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_alrnf56T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qS9lxrsb, 0, m, &cVar_qS9lxrsb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fSxFmDQa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7EygMUr9, HV_BINOP_MULTIPLY, 0, m, &cBinop_7EygMUr9_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_p0mWooV2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wNMvUoqL, HV_BINOP_MULTIPLY, 0, m, &cBinop_wNMvUoqL_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TL0bF63p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ImmER6oC, HV_BINOP_MULTIPLY, 0, m, &cBinop_ImmER6oC_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_kyR6Uf9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OytetkHo, HV_BINOP_MULTIPLY, 0, m, &cBinop_OytetkHo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4PB45DRj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_u7CLUdjX, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_vUtKEICK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BKv0ZQ84, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_RqZ8Bnqn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WIQAcIbv, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_zl8wGrV3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_f1DGJdvU, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_Ki4AybLG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vJxh4Cvg, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_trU9TGwk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hI2ZB54L_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_hI2ZB54L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OUc6DMhd, HV_BINOP_DIVIDE, 1, m, &cBinop_OUc6DMhd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ws4CSnOG_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_wsfgUdHI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_DibGLyWq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lDO08RpC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_wsfgUdHI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DibGLyWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OUc6DMhd, HV_BINOP_DIVIDE, 0, m, &cBinop_OUc6DMhd_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Ws4CSnOG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lDO08RpC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_OUc6DMhd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OwzaUmoZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_OwzaUmoZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OwzaUmoZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lZTqfkAI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bkg35FHZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_d41JTQSB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6rapU8oT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_8Are85zR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YcM07sTX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_W5TKPxd9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_v0fycHkB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_v0fycHkB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OwzaUmoZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_OwzaUmoZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_a023JzFS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_chCjt3yK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_chCjt3yK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i4CyM1ZY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_D2j6AE0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lrQUFgtw, HV_BINOP_MULTIPLY, 1, m, &cBinop_lrQUFgtw_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_VE7s46OD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_BmqhbtVg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BmqhbtVg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_D2j6AE0r_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Tqgyo3XQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_T6r5eL67_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_T6r5eL67_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ln7fYe1V, HV_BINOP_MULTIPLY, 1, m, &cBinop_ln7fYe1V_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Pm8J1ldU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k0xyHOD9, HV_BINOP_MULTIPLY, 1, m, &cBinop_k0xyHOD9_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kjOxJX2T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HkXBVFgA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HkXBVFgA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Pm8J1ldU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_W5s6T5sC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mxmaOxTz, 1, m, &cVar_mxmaOxTz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hkh9LqEK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zx3IRNE8, HV_BINOP_MULTIPLY, 1, m, &cBinop_zx3IRNE8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_KIDoWnlp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_XqIMBSow_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XqIMBSow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RWT1XW0O, HV_BINOP_MULTIPLY, 1, m, &cBinop_RWT1XW0O_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_mxmaOxTz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fRCGiHol_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_zPPHzmN4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_19iG6wGg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_W5TKPxd9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wWDJW1bn_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Ea2943m1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_a023JzFS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bkg35FHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_8Are85zR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_lZTqfkAI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_d41JTQSB_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_6rapU8oT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_o8Frug87_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_YcM07sTX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_187foEsP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_HxMQucnk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AW26Cqif_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_i4CyM1ZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_nI3mafmv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nI3mafmv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JLvllVCD, HV_BINOP_MULTIPLY, 1, m, &cBinop_JLvllVCD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JLvllVCD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ghgABW8P_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ghgABW8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HxMQucnk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_fRCGiHol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_rqb1Iw3B_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rqb1Iw3B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cDgcByPs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_j5XQW9q8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_f9JGUUnY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Darkc591_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ms1ZNjaz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yaL9vvPw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lrQUFgtw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4PB45DRj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ln7fYe1V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vUtKEICK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_k0xyHOD9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RqZ8Bnqn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_zx3IRNE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zl8wGrV3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_RWT1XW0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ki4AybLG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Mt22rSHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zPPHzmN4, 0, m, &cVar_zPPHzmN4_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_grwlQyxZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ea2943m1, 1, m, &cVar_Ea2943m1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yaL9vvPw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lrQUFgtw, HV_BINOP_MULTIPLY, 0, m, &cBinop_lrQUFgtw_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_f9JGUUnY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zx3IRNE8, HV_BINOP_MULTIPLY, 0, m, &cBinop_zx3IRNE8_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Ms1ZNjaz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ln7fYe1V, HV_BINOP_MULTIPLY, 0, m, &cBinop_ln7fYe1V_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_j5XQW9q8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RWT1XW0O, HV_BINOP_MULTIPLY, 0, m, &cBinop_RWT1XW0O_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Darkc591_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k0xyHOD9, HV_BINOP_MULTIPLY, 0, m, &cBinop_k0xyHOD9_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cDgcByPs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_wWDJW1bn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mxmaOxTz, 0, m, &cVar_mxmaOxTz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_19iG6wGg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ea2943m1, 0, m, &cVar_Ea2943m1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_r2KPqNoG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZwWsJI60, 1, m, &cIf_ZwWsJI60_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Wv8i2rnI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_tCJ8XUM2, m);
}

void Heavy_WSTD_DL3Y::cBinop_hUwwYM9q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Wv8i2rnI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_BthAkdJd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZwWsJI60, 0, m, &cIf_ZwWsJI60_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_YQ36suUn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PmrINZl9, 0, m, &cSlice_PmrINZl9_sendMessage);
      break;
    }
    default: {
      cSwitchcase_iglZGGnG_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_PmrINZl9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_X6sj6y6I_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_X6sj6y6I_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_HFSnbzmu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_X6sj6y6I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_X6sj6y6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WBAhwWI8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_CZNMoKGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_IF3N49Nl_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_d38YRVuu, 0, m, &cIf_d38YRVuu_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_d38YRVuu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Q4ZqBMMk_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_BWxl6RDn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_PObvagfT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_Hzf6E8p0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_FsnGAEA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_iXajQOIT, HV_BINOP_POW, 0, m, &cBinop_iXajQOIT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iXajQOIT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0bfluVlz, 0, m, &cIf_0bfluVlz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_46DCRvIz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_CGwMBEd9_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8kS3o0hQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_DJOfJUnU_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_j1HsPlCT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BWxl6RDn, 0, m, &cIf_BWxl6RDn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DJOfJUnU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BWxl6RDn, 1, m, &cIf_BWxl6RDn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Hzf6E8p0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_46DCRvIz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PObvagfT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_0bfluVlz, 0, m, &cIf_0bfluVlz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CGwMBEd9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iXajQOIT, HV_BINOP_POW, 1, m, &cBinop_iXajQOIT_sendMessage);
  cMsg_FsnGAEA9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_0bfluVlz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_NWLA7g28, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_IF3N49Nl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_d38YRVuu, 1, m, &cIf_d38YRVuu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Q4ZqBMMk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AibsBG2i, HV_BINOP_GREATER_THAN, 1, m, &cBinop_AibsBG2i_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xoKv3q6I, HV_BINOP_EQ, 1, m, &cBinop_xoKv3q6I_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_gcdNTasp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_59Au4MRZ, HV_BINOP_ADD, 0, m, &cBinop_59Au4MRZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_59Au4MRZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8kS3o0hQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_j1HsPlCT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AibsBG2i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0bfluVlz, 1, m, &cIf_0bfluVlz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xoKv3q6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hL2DlyNH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_hL2DlyNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_NWLA7g28, m);
}

void Heavy_WSTD_DL3Y::cCast_cV1g3bhL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gcdNTasp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_TDpSIywa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_59Au4MRZ, HV_BINOP_ADD, 1, m, &cBinop_59Au4MRZ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AibsBG2i, HV_BINOP_GREATER_THAN, 0, m, &cBinop_AibsBG2i_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xoKv3q6I, HV_BINOP_EQ, 0, m, &cBinop_xoKv3q6I_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_CS0fEL9w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CZNMoKGu, 0, m, &cVar_CZNMoKGu_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Jrt5pYDn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_pYE7R9xh_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_OYRq2ALw, 0, m, &cIf_OYRq2ALw_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_OYRq2ALw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_hguR18Qw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_pWoHAGV3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_MgKCqoK9_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_mNVRB3AR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_JKXaUYbm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Wcd4fnN, HV_BINOP_POW, 0, m, &cBinop_2Wcd4fnN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2Wcd4fnN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_o66ERSgP, 0, m, &cIf_o66ERSgP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MFrXzBka_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_rj2iJWYr_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_n4vzEpgW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Lp1A9JML_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TzRxzPV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pWoHAGV3, 0, m, &cIf_pWoHAGV3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Lp1A9JML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pWoHAGV3, 1, m, &cIf_pWoHAGV3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mNVRB3AR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_MFrXzBka_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MgKCqoK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_o66ERSgP, 0, m, &cIf_o66ERSgP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rj2iJWYr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Wcd4fnN, HV_BINOP_POW, 1, m, &cBinop_2Wcd4fnN_sendMessage);
  cMsg_JKXaUYbm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_o66ERSgP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_iNDUxOKo_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ffXsWf7v_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_AYeVuMes_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_pYE7R9xh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OYRq2ALw, 1, m, &cIf_OYRq2ALw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hguR18Qw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qaOwSmsF, HV_BINOP_GREATER_THAN, 1, m, &cBinop_qaOwSmsF_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7jcKMWRf, HV_BINOP_EQ, 1, m, &cBinop_7jcKMWRf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_3K8UOj0L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_57VhYWye, HV_BINOP_ADD, 0, m, &cBinop_57VhYWye_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_57VhYWye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n4vzEpgW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TzRxzPV8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qaOwSmsF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_o66ERSgP, 1, m, &cIf_o66ERSgP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7jcKMWRf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wuBQWrHz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_wuBQWrHz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_iNDUxOKo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ffXsWf7v_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_AYeVuMes_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_dNDPrhkR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Jrt5pYDn, 0, m, &cVar_Jrt5pYDn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_aqKxI3Y3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3K8UOj0L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_nXOmtxOb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_57VhYWye, HV_BINOP_ADD, 1, m, &cBinop_57VhYWye_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qaOwSmsF, HV_BINOP_GREATER_THAN, 0, m, &cBinop_qaOwSmsF_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7jcKMWRf, HV_BINOP_EQ, 0, m, &cBinop_7jcKMWRf_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_epNyGda0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_T28jCJ2r_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_5cWCsixK, 0, m, &cIf_5cWCsixK_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_5cWCsixK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ZDIDh4ZP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_AZiJz5yj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Vuk1DneO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_ktFVvQdS_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_7qipbNU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vsiy5Npu, HV_BINOP_POW, 0, m, &cBinop_Vsiy5Npu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Vsiy5Npu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EE4HmnkI, 0, m, &cIf_EE4HmnkI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Agweqt9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_o7roQapp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_mbTIITxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_nHYl89kp_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_y6RPhtQZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AZiJz5yj, 0, m, &cIf_AZiJz5yj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nHYl89kp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AZiJz5yj, 1, m, &cIf_AZiJz5yj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ktFVvQdS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Agweqt9d_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Vuk1DneO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_EE4HmnkI, 0, m, &cIf_EE4HmnkI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_o7roQapp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vsiy5Npu, HV_BINOP_POW, 1, m, &cBinop_Vsiy5Npu_sendMessage);
  cMsg_7qipbNU5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cIf_EE4HmnkI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_dhgRowel, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_T28jCJ2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5cWCsixK, 1, m, &cIf_5cWCsixK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZDIDh4ZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SQu6pKGt, HV_BINOP_GREATER_THAN, 1, m, &cBinop_SQu6pKGt_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_LCv9s81p, HV_BINOP_EQ, 1, m, &cBinop_LCv9s81p_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6BM7jF3w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_0OwmO8St, HV_BINOP_ADD, 0, m, &cBinop_0OwmO8St_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0OwmO8St_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mbTIITxL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y6RPhtQZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SQu6pKGt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EE4HmnkI, 1, m, &cIf_EE4HmnkI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LCv9s81p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v22LpJkA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_v22LpJkA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_dhgRowel, m);
}

void Heavy_WSTD_DL3Y::cCast_nMeBHQLL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6BM7jF3w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_r4S6nF9W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0OwmO8St, HV_BINOP_ADD, 1, m, &cBinop_0OwmO8St_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_SQu6pKGt, HV_BINOP_GREATER_THAN, 0, m, &cBinop_SQu6pKGt_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_LCv9s81p, HV_BINOP_EQ, 0, m, &cBinop_LCv9s81p_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_FEvctQox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_epNyGda0, 0, m, &cVar_epNyGda0_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_tZhKbANh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_OmqMZ123, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSwitchcase_Dh3tnP65_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_TZ77hxEN, 0, m, &cSlice_TZ77hxEN_sendMessage);
      break;
    }
    default: {
      cSwitchcase_mBVjDQYR_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_TZ77hxEN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_akWKQQGL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_akWKQQGL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_S52nkQ35_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_akWKQQGL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_akWKQQGL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YHgfewaV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_mBVjDQYR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_sAbi9MZ6, 0, m, &cSlice_sAbi9MZ6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_YQ36suUn_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_sAbi9MZ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_cfE7rsmZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_cfE7rsmZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_BRbGdHJ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cfE7rsmZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_cfE7rsmZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wEgMAHNe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_iglZGGnG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_eVVCLV3y, 0, m, &cSlice_eVVCLV3y_sendMessage);
      break;
    }
    default: {
      cSwitchcase_xIt6uKb2_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_eVVCLV3y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_no8G4Zsy_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_no8G4Zsy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_VXMoJ0xC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_no8G4Zsy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_no8G4Zsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5HpT3tlU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_xIt6uKb2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_njRFjJ5M, 0, m, &cSlice_njRFjJ5M_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_njRFjJ5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_knaaxVWL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_knaaxVWL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_x67ET3YF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_knaaxVWL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_knaaxVWL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lcHXCE7c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_mwiXL00Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_g710SEAi, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_YhpMoWq6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bcKpJuhl, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_DKtb4utw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gUT38zaz, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_08m7kQde_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JmRA0MNW, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_9tIyJYrC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UbTnf1LI, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_hxyK3mWD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_H8ZXZ7Vq_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_H8ZXZ7Vq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RpWuKXDJ, HV_BINOP_DIVIDE, 1, m, &cBinop_RpWuKXDJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A1xKaTpm_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_zoxIrRat_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_dP6CACAu_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_S2QDEMvp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_zoxIrRat_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dP6CACAu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RpWuKXDJ, HV_BINOP_DIVIDE, 0, m, &cBinop_RpWuKXDJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_A1xKaTpm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_S2QDEMvp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_RpWuKXDJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wxJK9Yqg, HV_BINOP_MULTIPLY, 1, m, &cBinop_wxJK9Yqg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wxJK9Yqg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d2pv4XD4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kIPZQ4zo_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_fzYietD5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_l3QArF6P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_6gDziBiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_er8f0pt4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_qRh3lX6s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_GIM5PGb8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GIM5PGb8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wxJK9Yqg, HV_BINOP_MULTIPLY, 0, m, &cBinop_wxJK9Yqg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vmKnVQLy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_01Vj0Gnw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_01Vj0Gnw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H2X3jouY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_fsDxUEEy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ekagkfq5, 1, m, &cVar_ekagkfq5_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_ekagkfq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mepHgQrD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_w6wHgmFA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CTA0gvK1, HV_BINOP_MULTIPLY, 1, m, &cBinop_CTA0gvK1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qNkMfPaf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_w6wHgmFA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yYKnofjO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_mXEMFtzV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mXEMFtzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UTVuaMls, HV_BINOP_MULTIPLY, 1, m, &cBinop_UTVuaMls_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_e3JQKyec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jASeFPqP, HV_BINOP_MULTIPLY, 1, m, &cBinop_jASeFPqP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WmZ4y0Kr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_e3JQKyec_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_skWmWj5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H1fA7WFT, HV_BINOP_MULTIPLY, 1, m, &cBinop_H1fA7WFT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pVSLhzCS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_FXbOWTNR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FXbOWTNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lesitg4n, HV_BINOP_MULTIPLY, 1, m, &cBinop_Lesitg4n_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_EBAXsYgY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Kh6cOm6S_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_qRh3lX6s_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SyAKanuA_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_co1FloiR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_vmKnVQLy_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_kIPZQ4zo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_6gDziBiT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_d2pv4XD4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_fzYietD5_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_l3QArF6P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YvFhO41Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_er8f0pt4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lcrQtmg4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_eP14qHTb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HpxgKr8Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_H2X3jouY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_iSw8DfJ8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iSw8DfJ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rXxsQpn1, HV_BINOP_MULTIPLY, 1, m, &cBinop_rXxsQpn1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rXxsQpn1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_41nF8jHS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_41nF8jHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eP14qHTb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_mepHgQrD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_dx8BJNOV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dx8BJNOV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FEJvYlZx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9nGaH4Pw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TUbZXZg7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4h39Zwha_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lkulu5hx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BXASPusf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CTA0gvK1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mwiXL00Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_UTVuaMls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YhpMoWq6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_jASeFPqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DKtb4utw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_H1fA7WFT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_08m7kQde_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Lesitg4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9tIyJYrC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_aKBJgfit_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EBAXsYgY, 0, m, &cVar_EBAXsYgY_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_t6NxKYQ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_co1FloiR, 1, m, &cVar_co1FloiR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4h39Zwha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jASeFPqP, HV_BINOP_MULTIPLY, 0, m, &cBinop_jASeFPqP_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_FEJvYlZx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_BXASPusf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CTA0gvK1, HV_BINOP_MULTIPLY, 0, m, &cBinop_CTA0gvK1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_TUbZXZg7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H1fA7WFT, HV_BINOP_MULTIPLY, 0, m, &cBinop_H1fA7WFT_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_lkulu5hx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UTVuaMls, HV_BINOP_MULTIPLY, 0, m, &cBinop_UTVuaMls_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_9nGaH4Pw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lesitg4n, HV_BINOP_MULTIPLY, 0, m, &cBinop_Lesitg4n_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SyAKanuA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ekagkfq5, 0, m, &cVar_ekagkfq5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Kh6cOm6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_co1FloiR, 0, m, &cVar_co1FloiR_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Rutv9ilc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oQd2rxIY, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_uJJhkbqK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XtxaQvlg, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_5aJdudlt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FPQC4mQQ, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_UTk5pEdT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5NzbOYOl, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_HGZuVrmJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FNB6oHur_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_FNB6oHur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XOAJYDaS, HV_BINOP_DIVIDE, 1, m, &cBinop_XOAJYDaS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ksI3cjIq_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_N09hECXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_cPcRPDzm_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_64SbjjfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_N09hECXF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cPcRPDzm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XOAJYDaS, HV_BINOP_DIVIDE, 0, m, &cBinop_XOAJYDaS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ksI3cjIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_64SbjjfY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_XOAJYDaS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rleJzxaQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_rleJzxaQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rleJzxaQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jfi23dO8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4CQhdbwP_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_8s986Xjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jgKmPZxp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_4ZG2SIe6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_it1bux5K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_OOxb9J9x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_5Z9L0PKU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5Z9L0PKU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rleJzxaQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_rleJzxaQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nq3cCzCb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_pIcayQ6d_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pIcayQ6d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0rUhFFkS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_46gvDkPe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QtL6n8r3, HV_BINOP_MULTIPLY, 1, m, &cBinop_QtL6n8r3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YZNj2Qif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JnAi2EXW, 1, m, &cVar_JnAi2EXW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dhCFjN1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9E6f7olH, HV_BINOP_MULTIPLY, 1, m, &cBinop_9E6f7olH_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cm3raErm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_OsLWt0pf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OsLWt0pf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ta0rLrbo, HV_BINOP_MULTIPLY, 1, m, &cBinop_Ta0rLrbo_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_JnAi2EXW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dtEWSHs2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_wr6KGGeN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_10O40qW3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_OOxb9J9x_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fdhkv6gn_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_FshHCpUl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_nq3cCzCb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4CQhdbwP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_4ZG2SIe6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jfi23dO8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_8s986Xjp_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_jgKmPZxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zBfj5idJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_it1bux5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sJoBkXIP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_kGJzKXOp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Q4GA74OE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_0rUhFFkS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_CC63zpCv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CC63zpCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zwkYmD3N, HV_BINOP_MULTIPLY, 1, m, &cBinop_zwkYmD3N_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zwkYmD3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_rqeqg8I8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_rqeqg8I8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kGJzKXOp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_dtEWSHs2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_UkfhbJvU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UkfhbJvU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fPJZFJSf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vZxHpRvz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GeKzvVbJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Pa2tGjgH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jlEt08Ff_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Rutv9ilc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_QtL6n8r3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uJJhkbqK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_9E6f7olH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5aJdudlt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Ta0rLrbo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UTk5pEdT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_R8WDRdUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wr6KGGeN, 0, m, &cVar_wr6KGGeN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_YisjkWbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FshHCpUl, 1, m, &cVar_FshHCpUl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fdhkv6gn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JnAi2EXW, 0, m, &cVar_JnAi2EXW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_10O40qW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FshHCpUl, 0, m, &cVar_FshHCpUl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vZxHpRvz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9E6f7olH, HV_BINOP_MULTIPLY, 0, m, &cBinop_9E6f7olH_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Pa2tGjgH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jlEt08Ff, HV_BINOP_MULTIPLY, 0, m, &cBinop_jlEt08Ff_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_fPJZFJSf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ta0rLrbo, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ta0rLrbo_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_GeKzvVbJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QtL6n8r3, HV_BINOP_MULTIPLY, 0, m, &cBinop_QtL6n8r3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9bk2EMv6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mpYBqQbF, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_tRy0uUhB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nNMNxeFp, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_M1yjQ24g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jkfFCd70, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_v77g1EAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DQSIZ7Ji, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_6S0dQm1v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Yp8UFEAS, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_OO0Po02C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_yRWimjb1_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_yRWimjb1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wb0C6g5O, HV_BINOP_DIVIDE, 1, m, &cBinop_wb0C6g5O_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bjzgs5c3_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_dzOH9cCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_tJWppTf5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YaU7pq57_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_dzOH9cCk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tJWppTf5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wb0C6g5O, HV_BINOP_DIVIDE, 0, m, &cBinop_wb0C6g5O_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_bjzgs5c3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YaU7pq57_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_wb0C6g5O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ytDydfkh, HV_BINOP_MULTIPLY, 1, m, &cBinop_ytDydfkh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ytDydfkh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_clch5Zsr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NEt4Jnmz_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_UFAC3iEL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_teND1KTE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_drnQI8UO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_e5bRm6ZE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ENZkI31E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_hqIxKiur_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hqIxKiur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ytDydfkh, HV_BINOP_MULTIPLY, 0, m, &cBinop_ytDydfkh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lchvAjjG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_EDfHOj7f_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EDfHOj7f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h9l6cHDD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Gs40ySl3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vVffNvLZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_vVffNvLZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_CbV6nvD3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_cfYY0zro_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cfYY0zro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Gs40ySl3_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zQLrXMaW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_TTp6KZDZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TTp6KZDZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nKzSQA8R, HV_BINOP_MULTIPLY, 1, m, &cBinop_nKzSQA8R_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WkWCG87v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c5MHlenX, HV_BINOP_MULTIPLY, 1, m, &cBinop_c5MHlenX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0BTiaYZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_FCOuleaN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FCOuleaN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_WkWCG87v_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JxTM80mt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SekYz6iy, 1, m, &cVar_SekYz6iy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oYgiI53Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BUYvBiVK, HV_BINOP_MULTIPLY, 1, m, &cBinop_BUYvBiVK_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_AD58mrMe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_67EFEbdo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_67EFEbdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BwmlDwH2, HV_BINOP_MULTIPLY, 1, m, &cBinop_BwmlDwH2_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_SekYz6iy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1WZ8ToUk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_14VmvNF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ydfAJv7C_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_ENZkI31E_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OCznBhzs_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_8RYASZS9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_lchvAjjG_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NEt4Jnmz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_drnQI8UO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_clch5Zsr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_UFAC3iEL_sendMessage);
}

void Heavy_WSTD_DL3Y::cSend_teND1KTE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NTIern86_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_e5bRm6ZE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_M15RNXyW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_agncZJtP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5b791AMa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_h9l6cHDD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_vMxtnGJG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vMxtnGJG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pcMt1H0v, HV_BINOP_MULTIPLY, 1, m, &cBinop_pcMt1H0v_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pcMt1H0v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_n4xfahzg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_n4xfahzg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_agncZJtP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_1WZ8ToUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_3rUOtnxT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3rUOtnxT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZpvubFzv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ycEnhMrE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_utax4p38_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sHoSFDXV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DEzWmLXy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZCeuHvgx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_vVffNvLZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9bk2EMv6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_nKzSQA8R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tRy0uUhB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_c5MHlenX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_M1yjQ24g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_BUYvBiVK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v77g1EAi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_BwmlDwH2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6S0dQm1v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Hv1kjSBz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_14VmvNF3, 0, m, &cVar_14VmvNF3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_i1CArPjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8RYASZS9, 1, m, &cVar_8RYASZS9_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_utax4p38_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BUYvBiVK, HV_BINOP_MULTIPLY, 0, m, &cBinop_BUYvBiVK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DEzWmLXy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nKzSQA8R, HV_BINOP_MULTIPLY, 0, m, &cBinop_nKzSQA8R_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ycEnhMrE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BwmlDwH2, HV_BINOP_MULTIPLY, 0, m, &cBinop_BwmlDwH2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_sHoSFDXV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c5MHlenX, HV_BINOP_MULTIPLY, 0, m, &cBinop_c5MHlenX_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ZpvubFzv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_DL3Y::cCast_ZCeuHvgx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vVffNvLZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_vVffNvLZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_OCznBhzs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SekYz6iy, 0, m, &cVar_SekYz6iy_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ydfAJv7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8RYASZS9, 0, m, &cVar_8RYASZS9_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iNDUxOKo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tZhKbANh, 1, m, &cIf_tZhKbANh_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ScTB1bq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_OmqMZ123, m);
}

void Heavy_WSTD_DL3Y::cBinop_ffXsWf7v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ScTB1bq8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_AYeVuMes_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tZhKbANh, 0, m, &cIf_tZhKbANh_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_H78fpCa7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t8XiNxrE, HV_BINOP_DIVIDE, 0, m, &cBinop_t8XiNxrE_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_F6tEV1yv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9t8RsZtg, HV_BINOP_DIVIDE, 1, m, &cBinop_9t8RsZtg_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_t8XiNxrE, HV_BINOP_DIVIDE, 1, m, &cBinop_t8XiNxrE_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_rPVNifUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WcZVJCxa, HV_BINOP_DIVIDE, 0, m, &cBinop_WcZVJCxa_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_R0hPef0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WcZVJCxa, HV_BINOP_DIVIDE, 1, m, &cBinop_WcZVJCxa_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4xSxoZpl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_H78fpCa7, 0, m, &cVar_H78fpCa7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_BwPIi1tR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_F6tEV1yv, 0, m, &cVar_F6tEV1yv_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_5gUfuh4w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9t8RsZtg, HV_BINOP_DIVIDE, 0, m, &cBinop_9t8RsZtg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9t8RsZtg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_rPVNifUk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_t8XiNxrE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_R0hPef0U_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_WcZVJCxa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_L460kH0B_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_ppHbvbmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_JCWOHRaJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yDwK6Mds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_aYrHIvND_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_L460kH0B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_yDwK6Mds_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aYrHIvND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_ppHbvbmA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JCWOHRaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rI9PsLR7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_HIcib3vF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uAz0IUxW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_Z1bOiHrq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UxUPbdoO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_1QqZJ2dt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TyNVIOln_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_RMDuOn6A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4jFZFHis_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_01UEqjl1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CwzQSC4s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_JRRPP6HI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X8Ugq0jy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_VV6qcL92_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UDsQHVKv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_4FP6U4iV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_k0TZoDdF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_kkHPw3JI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GQSEVbOC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_ajVwMvq4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_miB9eA3S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_AtrdkoUE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4SHZoNEO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_gDNwohAn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c4WFp31l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_EropYodE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_bskCx97a, 0, m, &cSlice_bskCx97a_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_bskCx97a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7wS5q5RX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7wS5q5RX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_CYGfkcI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7wS5q5RX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_7wS5q5RX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LxBaMFtc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_NMJz1Xes_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4mtfwDNt, 0, m, &cSlice_4mtfwDNt_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Lty6bxoa_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_4mtfwDNt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_i3UVRI2e_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_i3UVRI2e_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_Od6YCvBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_i3UVRI2e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_i3UVRI2e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7mxGoF1X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_qgqlJYLc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_bBGn3tfj, 0, m, &cSlice_bBGn3tfj_sendMessage);
      break;
    }
    default: {
      cSwitchcase_EropYodE_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_bBGn3tfj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_itgZXsRo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_itgZXsRo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_NbUU5fxS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_itgZXsRo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_itgZXsRo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OOQXJ5G3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Xk3fzRoH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_5EKDTXPV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5EKDTXPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_S9fRuCMa_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_hzLF4XpR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0zy13yZX_sendMessage(_c, 0, m);
  cMsg_1HuH99vu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_s85TCbC4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nl4UzkLh_sendMessage(_c, 0, m);
  cMsg_8xLzKf7O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_S9fRuCMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_tUUEObLx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tUUEObLx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TlqoJfEn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5xcsgy7r_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_5xcsgy7r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HYJl9pF2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_TlqoJfEn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_8BAWvgdY_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_8BAWvgdY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_UQ9RG0qO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_HYJl9pF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_So9yWT8V_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_So9yWT8V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_u4IocU6W_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UQ9RG0qO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_hzLF4XpR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_u4IocU6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_s85TCbC4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VxGZVIsO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_B5f4Kwud_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_B5f4Kwud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_7TQ3oeUe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7TQ3oeUe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_69RV8zAh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_69RV8zAh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0Tvi0Sue_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qjgOh3Io_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_qjgOh3Io_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_s0wnxnU5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_0Tvi0Sue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ksIJFq6Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ksIJFq6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Kq6YivWD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_s0wnxnU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_gNjKIieP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gNjKIieP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Cymvezn5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Cymvezn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2oCRRtXc_sendMessage(_c, 0, m);
  cMsg_eMZRb1mz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Kq6YivWD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zrqYWCRs_sendMessage(_c, 0, m);
  cMsg_tDpq3U0r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_9SchJnGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_JJXmEBFG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JJXmEBFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_pQPR59cP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_6c8I6RId_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_X8IxcfBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_80LK6DIj_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1JVJjtfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_TKilIG40_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_TKilIG40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XEzTmUOp, HV_BINOP_DIVIDE, 1, m, &cBinop_XEzTmUOp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pQPR59cP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_dyWNYkUu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dyWNYkUu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_GVUhSYk3, m);
}

void Heavy_WSTD_DL3Y::cMsg_d65Pabsq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_SPucsSA0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SPucsSA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_9SchJnGj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6c8I6RId_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_C4puBAOZ, m);
}

void Heavy_WSTD_DL3Y::cBinop_80LK6DIj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_VgZiQbIn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VgZiQbIn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XEzTmUOp, HV_BINOP_DIVIDE, 0, m, &cBinop_XEzTmUOp_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XEzTmUOp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d65Pabsq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_H7IvwzMr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_SRrgWXkU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SRrgWXkU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_jOL0kKE1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_C1plvgu8_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_SiMQL5Q8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_xx0qmyiI_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_hdIbmwMh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_5bLAiej7_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_5bLAiej7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z3JieaBf, HV_BINOP_DIVIDE, 1, m, &cBinop_Z3JieaBf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jOL0kKE1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_bgaIrcUF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bgaIrcUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_BddhWH9f, m);
}

void Heavy_WSTD_DL3Y::cMsg_npVGbK8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_BSJa7Zf8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BSJa7Zf8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_H7IvwzMr_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_C1plvgu8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_47fjI4x8, m);
}

void Heavy_WSTD_DL3Y::cBinop_xx0qmyiI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_45vDGlke_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_45vDGlke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z3JieaBf, HV_BINOP_DIVIDE, 0, m, &cBinop_Z3JieaBf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Z3JieaBf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_npVGbK8Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_MYQbQPF5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qMxf9MM7, HV_BINOP_MULTIPLY, 0, m, &cBinop_qMxf9MM7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mCB3GPB0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_bHLJZoqj_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_bHLJZoqj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BD99lRub_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_qMxf9MM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_cheOPdwf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qKfZiJwc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qMxf9MM7, HV_BINOP_MULTIPLY, 1, m, &cBinop_qMxf9MM7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BD99lRub_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qKfZiJwc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cheOPdwf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ffxGCR1n_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ffxGCR1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_CuTCZ3ZX_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_SrSRaCdO, m);
}

void Heavy_WSTD_DL3Y::cBinop_CuTCZ3ZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_kxbOVXOL, m);
}

void Heavy_WSTD_DL3Y::cVar_XvztEAth_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ueOZflAA, HV_BINOP_MULTIPLY, 0, m, &cBinop_ueOZflAA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_z8D1ZTnW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VX5txrMz_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_VX5txrMz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bAEfWjHH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ueOZflAA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_pLl0pA1R_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JSPcCNMJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ueOZflAA, HV_BINOP_MULTIPLY, 1, m, &cBinop_ueOZflAA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bAEfWjHH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_JSPcCNMJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pLl0pA1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_B1HBldMc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_B1HBldMc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_aJUCO2qu_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_hDJ2Rwln, m);
}

void Heavy_WSTD_DL3Y::cBinop_aJUCO2qu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_EXVAPhov, m);
}

void Heavy_WSTD_DL3Y::sEnv_R7KMdNr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EBJ9Zh87_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AcppAOTj_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_JrPOY8Iq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_a3rLbq6w_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_7Y5Jul1Z_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_gWsFrJpm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_eMdLygJs, HV_BINOP_POW, 0, m, &cBinop_eMdLygJs_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eMdLygJs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4l2pqLui_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_oUNuJ9QX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_vS8UIyug_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EBJ9Zh87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_6s5tmae9_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_AcppAOTj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JrPOY8Iq, 0, m, &cIf_JrPOY8Iq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6s5tmae9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JrPOY8Iq, 1, m, &cIf_JrPOY8Iq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7Y5Jul1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_oUNuJ9QX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_a3rLbq6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_4l2pqLui_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_vS8UIyug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eMdLygJs, HV_BINOP_POW, 1, m, &cBinop_eMdLygJs_sendMessage);
  cMsg_gWsFrJpm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_R75NEsvO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x5hupr4N, HV_BINOP_MULTIPLY, 0, m, &cBinop_x5hupr4N_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6rpITQY7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ONxrtwK9_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ONxrtwK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Duc9rZia_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_x5hupr4N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_syOyjU5e_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uhTuykvg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x5hupr4N, HV_BINOP_MULTIPLY, 1, m, &cBinop_x5hupr4N_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Duc9rZia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_uhTuykvg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_syOyjU5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_gSAW0ySB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gSAW0ySB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_PZWtKqRr_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_x7vQuWH9, m);
}

void Heavy_WSTD_DL3Y::cBinop_PZWtKqRr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_w8sWCTUd, m);
}

void Heavy_WSTD_DL3Y::cMsg_4l2pqLui_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_AJgfo1HK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_AJgfo1HK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_7JAhamID, m);
}

void Heavy_WSTD_DL3Y::sEnv_BPLru1Ws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_r4lLR92j_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zG6SZJ4U_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_BakUPGMx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_S7WxNtJJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_o9v8zTf1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_mGCDQ76x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_P2ytd1vG, HV_BINOP_POW, 0, m, &cBinop_P2ytd1vG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_P2ytd1vG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZKSjgExl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_b25lm65h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_IDKMxf5j_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_zG6SZJ4U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BakUPGMx, 0, m, &cIf_BakUPGMx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_r4lLR92j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_bnuWhUpF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bnuWhUpF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BakUPGMx, 1, m, &cIf_BakUPGMx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_o9v8zTf1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_b25lm65h_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_S7WxNtJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_ZKSjgExl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_IDKMxf5j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P2ytd1vG, HV_BINOP_POW, 1, m, &cBinop_P2ytd1vG_sendMessage);
  cMsg_mGCDQ76x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_qINp6PyF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vgv6Z6Mv, HV_BINOP_MULTIPLY, 0, m, &cBinop_Vgv6Z6Mv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_9Pr4PUKJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_DipeIHI7_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_DipeIHI7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iMOMDRr9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Vgv6Z6Mv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_BDDnY0rR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JO8cjjHo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vgv6Z6Mv, HV_BINOP_MULTIPLY, 1, m, &cBinop_Vgv6Z6Mv_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_iMOMDRr9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_JO8cjjHo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BDDnY0rR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_KjGljZCi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_KjGljZCi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_sGT3K03d_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_4EdKcnoH, m);
}

void Heavy_WSTD_DL3Y::cBinop_sGT3K03d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_vgDHB84c, m);
}

void Heavy_WSTD_DL3Y::cMsg_ZKSjgExl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_lc9OqdlV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_lc9OqdlV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_LqnSAJ94, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Lty6bxoa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DXQUm44S, 0, m, &cSlice_DXQUm44S_sendMessage);
      break;
    }
    default: {
      cSwitchcase_qgqlJYLc_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_DXQUm44S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_AK4EXVMH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_AK4EXVMH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_lYv5QyXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AK4EXVMH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_AK4EXVMH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JzO02vEi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_Km9vmlqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CurMbV8F_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_CurMbV8F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_1jVoEyl4_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_tJUiNGKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tJUiNGKp, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_u6lR5uww, 0, m, &cDelay_u6lR5uww_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tJUiNGKp, 0, m, &cDelay_tJUiNGKp_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_e3nhwujO, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_u6lR5uww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_u6lR5uww, m);
  cMsg_Cvl8qkPo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_8pHan6kF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_w41QWJsS_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_0uQyrJIa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cQi4JocZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_2TJiAnQM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fBiEq2by_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_tJUiNGKp, 2, m, &cDelay_tJUiNGKp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3GnJGJuG_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cQi4JocZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_2TJiAnQM, 0, m, &hTable_2TJiAnQM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_1jVoEyl4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_0uQyrJIa_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Cvl8qkPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_2TJiAnQM, 0, m, &hTable_2TJiAnQM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3GnJGJuG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tJUiNGKp, 0, m, &cDelay_tJUiNGKp_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_fBiEq2by_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_u6lR5uww, 2, m, &cDelay_u6lR5uww_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_w41QWJsS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_e3nhwujO, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_4x4kdZJU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pW9EdCht, HV_BINOP_SUBTRACT, 0, m, &cBinop_pW9EdCht_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TfEs2GA6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_aXwYvyaU_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_aXwYvyaU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_jMNr2omT_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_PI4U6Mmn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BTQYbrbE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_Lc0ZQWPK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Lc0ZQWPK, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2i0JsUtX, 0, m, &cDelay_2i0JsUtX_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_YTAc1eGi, 0, m, &sTabread_YTAc1eGi_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_2i0JsUtX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2i0JsUtX, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_YTAc1eGi, 0, m, &sTabread_YTAc1eGi_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2i0JsUtX, 0, m, &cDelay_2i0JsUtX_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_YTAc1eGi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_XSGHRIrl, HV_BINOP_SUBTRACT, 0, m, &cBinop_XSGHRIrl_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_mT4STFHE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6lSEmWdw, HV_BINOP_MAX, 0, m, &cBinop_6lSEmWdw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jMNr2omT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mT4STFHE, HV_BINOP_MULTIPLY, 0, m, &cBinop_mT4STFHE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pW9EdCht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7HdvaZTq_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_YTAc1eGi, 0, m, &sTabread_YTAc1eGi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wn9YGJEt_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_Tcv0QgD7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XSGHRIrl, HV_BINOP_SUBTRACT, 1, m, &cBinop_XSGHRIrl_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2i0JsUtX, 2, m, &cDelay_2i0JsUtX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_BTQYbrbE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Tcv0QgD7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7HdvaZTq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Lc0ZQWPK, 0, m, &cDelay_Lc0ZQWPK_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2i0JsUtX, 0, m, &cDelay_2i0JsUtX_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PX0yIdqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_6lSEmWdw, HV_BINOP_MAX, 1, m, &cBinop_6lSEmWdw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6lSEmWdw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pW9EdCht, HV_BINOP_SUBTRACT, 1, m, &cBinop_pW9EdCht_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wn9YGJEt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Lc0ZQWPK, 0, m, &cDelay_Lc0ZQWPK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ZKEUmCkK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Lc0ZQWPK, 2, m, &cDelay_Lc0ZQWPK_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XSGHRIrl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ZKEUmCkK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_QkBVAxfX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PI4U6Mmn, 0, m, &cVar_PI4U6Mmn_sendMessage);
  cMsg_TfEs2GA6_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_4x4kdZJU, 0, m, &cTabhead_4x4kdZJU_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_sAMAY7uV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_mjs8X6tr_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_mjs8X6tr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_d7GaKl7O_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_hYDskwtN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hYDskwtN, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_0uOi5H0L, 0, m, &cDelay_0uOi5H0L_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hYDskwtN, 0, m, &cDelay_hYDskwtN_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_kSPc10lI, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_0uOi5H0L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0uOi5H0L, m);
  cMsg_6uvPyBPX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_yvfPoHCM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_LVHTv5Dj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_S31WwTWc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JzNA2uN8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_g3z6Jf22_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_s0HWT0KK_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hYDskwtN, 2, m, &cDelay_hYDskwtN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_atmDv4Xz_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_JzNA2uN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_g3z6Jf22, 0, m, &hTable_g3z6Jf22_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_d7GaKl7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_S31WwTWc_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6uvPyBPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_g3z6Jf22, 0, m, &hTable_g3z6Jf22_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_atmDv4Xz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hYDskwtN, 0, m, &cDelay_hYDskwtN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_s0HWT0KK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_0uOi5H0L, 2, m, &cDelay_0uOi5H0L_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_LVHTv5Dj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_kSPc10lI, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_5u8fXqna_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pEfbpW5i, HV_BINOP_SUBTRACT, 0, m, &cBinop_pEfbpW5i_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Nnxs0Enh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pansXkfv_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_pansXkfv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_BmJ6bPIJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_dwJzxV2b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FzbK1yPU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_rLK3plVx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rLK3plVx, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IQ6JvE7m, 0, m, &cDelay_IQ6JvE7m_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_FXx7x2fI, 0, m, &sTabread_FXx7x2fI_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_IQ6JvE7m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IQ6JvE7m, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_FXx7x2fI, 0, m, &sTabread_FXx7x2fI_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IQ6JvE7m, 0, m, &cDelay_IQ6JvE7m_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_FXx7x2fI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_4IcQqkIa, HV_BINOP_SUBTRACT, 0, m, &cBinop_4IcQqkIa_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_qrMbILk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x3k326Mk, HV_BINOP_MAX, 0, m, &cBinop_x3k326Mk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BmJ6bPIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qrMbILk8, HV_BINOP_MULTIPLY, 0, m, &cBinop_qrMbILk8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pEfbpW5i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mnQk5kgv_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_FXx7x2fI, 0, m, &sTabread_FXx7x2fI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_28PzwXgS_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_qz6GsQOO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4IcQqkIa, HV_BINOP_SUBTRACT, 1, m, &cBinop_4IcQqkIa_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IQ6JvE7m, 2, m, &cDelay_IQ6JvE7m_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_FzbK1yPU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qz6GsQOO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_mnQk5kgv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_rLK3plVx, 0, m, &cDelay_rLK3plVx_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IQ6JvE7m, 0, m, &cDelay_IQ6JvE7m_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xEu4GDwS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_x3k326Mk, HV_BINOP_MAX, 1, m, &cBinop_x3k326Mk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_x3k326Mk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pEfbpW5i, HV_BINOP_SUBTRACT, 1, m, &cBinop_pEfbpW5i_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_28PzwXgS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_rLK3plVx, 0, m, &cDelay_rLK3plVx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mC0AolLf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_rLK3plVx, 2, m, &cDelay_rLK3plVx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_4IcQqkIa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_mC0AolLf_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_OTXIh3vm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dwJzxV2b, 0, m, &cVar_dwJzxV2b_sendMessage);
  cMsg_Nnxs0Enh_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_5u8fXqna, 0, m, &cTabhead_5u8fXqna_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0zy13yZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6Q15kY8v, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_nl4UzkLh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fPL1nTbV, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_8xLzKf7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kNqIEllm, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_1HuH99vu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qC2PO2eF, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_tDpq3U0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Hrp3Pteq, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_2oCRRtXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_n4WfCNIw, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_zrqYWCRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_I10cEbaR, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_eMZRb1mz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dF9FGcNU, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_2sfCqWLW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CNfZgmT5, 0, m, &cSlice_CNfZgmT5_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_CNfZgmT5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_lvhGtpI3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_lvhGtpI3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_QqZgQQo0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lvhGtpI3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_lvhGtpI3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8W4hhjx5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_jD4pQGwa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5bzc19UV, 0, m, &cSlice_5bzc19UV_sendMessage);
      break;
    }
    default: {
      cSwitchcase_FQeHLIp5_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_5bzc19UV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_fY1AyWh2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_fY1AyWh2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_kyzIOww6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fY1AyWh2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_fY1AyWh2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4EGD97Mr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_3vhU3qu2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_JIlumW5t, 0, m, &cSlice_JIlumW5t_sendMessage);
      break;
    }
    default: {
      cSwitchcase_2sfCqWLW_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_JIlumW5t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Zmq9sFTp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Zmq9sFTp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_emYzPpJ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Zmq9sFTp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_Zmq9sFTp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_duyFzwf1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_hGkuJhJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ulMEE2pt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ulMEE2pt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_cc0hy1kN_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_A9t3HL4p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cQiUGLZN_sendMessage(_c, 0, m);
  cMsg_BMeDBwOk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_YVXEBOL6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_U0PDK9WX_sendMessage(_c, 0, m);
  cMsg_IKrRcKsO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_cc0hy1kN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_nCyM3aYh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nCyM3aYh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YfehwxWg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0yuBoBX3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_0yuBoBX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VeiJPc5b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_YfehwxWg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_u7FVTZti_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_u7FVTZti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_xE2qZYsy_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_VeiJPc5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_TbxV6yKk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TbxV6yKk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_oDMrtpbZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xE2qZYsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_A9t3HL4p_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oDMrtpbZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_YVXEBOL6_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XEsV3QUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_LxC26Tca_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LxC26Tca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_3bpByqmG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3bpByqmG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_wJnXqDiE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wJnXqDiE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_foFtqG0K_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_e416NneO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_e416NneO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qi06aY4r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_foFtqG0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_FJu9IyvA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FJu9IyvA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6AGWbshC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_qi06aY4r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_zqY3NgVy_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zqY3NgVy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_URSItPZe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_URSItPZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kMk6IVgp_sendMessage(_c, 0, m);
  cMsg_TE6C3qXt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_6AGWbshC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eVU2M2X3_sendMessage(_c, 0, m);
  cMsg_FymdXutK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_IjuewwjD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_yh269bdP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yh269bdP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ajycoC4t_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_XeVianvj_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_xUXetBxK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_P8Q3hbEk_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DGgZR3cj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tNpMqKJs_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_tNpMqKJs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IH2JIhuP, HV_BINOP_DIVIDE, 1, m, &cBinop_IH2JIhuP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ajycoC4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_9F6vR3yf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9F6vR3yf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_mokwH5ld, m);
}

void Heavy_WSTD_DL3Y::cMsg_g6cDcPSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_wP7eMtMv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wP7eMtMv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_IjuewwjD_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XeVianvj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_LOlQSmis, m);
}

void Heavy_WSTD_DL3Y::cBinop_P8Q3hbEk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_DWd2cGU8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DWd2cGU8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IH2JIhuP, HV_BINOP_DIVIDE, 0, m, &cBinop_IH2JIhuP_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_IH2JIhuP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g6cDcPSH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_oosxRRmM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_DMM6avas_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DMM6avas_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_sFLeZQOs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_cfvYUdGH_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_oyIcYOO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_Xa2a616n_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_WaKs7GDG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ckQWPU6W_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ckQWPU6W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_grf1JvHW, HV_BINOP_DIVIDE, 1, m, &cBinop_grf1JvHW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_sFLeZQOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_c8y8Gw3Z_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_c8y8Gw3Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_0oHZGur4, m);
}

void Heavy_WSTD_DL3Y::cMsg_BxGc7kJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_slFWWVBM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_slFWWVBM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_oosxRRmM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cfvYUdGH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_5c6VN4ks, m);
}

void Heavy_WSTD_DL3Y::cBinop_Xa2a616n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_kgIlCY9g_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_kgIlCY9g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_grf1JvHW, HV_BINOP_DIVIDE, 0, m, &cBinop_grf1JvHW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_grf1JvHW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BxGc7kJN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_MdUAbMMH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DxBMuHjg, HV_BINOP_MULTIPLY, 0, m, &cBinop_DxBMuHjg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_KJYI2hjF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_E0P17SKI_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_E0P17SKI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0aEntbLm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_DxBMuHjg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_LO2x0keB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ifQ6Hy8R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DxBMuHjg, HV_BINOP_MULTIPLY, 1, m, &cBinop_DxBMuHjg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_0aEntbLm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ifQ6Hy8R_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LO2x0keB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_o5cRKTUf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_o5cRKTUf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_gbpizOOx_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_KzbXvgt2, m);
}

void Heavy_WSTD_DL3Y::cBinop_gbpizOOx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_9PHF0dZB, m);
}

void Heavy_WSTD_DL3Y::cVar_to9gHNOr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GTFlITUC, HV_BINOP_MULTIPLY, 0, m, &cBinop_GTFlITUC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1EEcFj6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pfY4t4qN_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_pfY4t4qN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PYr07us8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_GTFlITUC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_csHNaogN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EQlAJ6JM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GTFlITUC, HV_BINOP_MULTIPLY, 1, m, &cBinop_GTFlITUC_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PYr07us8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_EQlAJ6JM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_csHNaogN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_DcvRCaQM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_DcvRCaQM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_IuzcPsPr_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_LK24UNKO, m);
}

void Heavy_WSTD_DL3Y::cBinop_IuzcPsPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_N7UIBDem, m);
}

void Heavy_WSTD_DL3Y::sEnv_7C53T0Pd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pJL7xXKE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HeWdu7Fi_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_qiY788Or_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_kKEsfyMR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_aHANnk5y_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_Vmt9h2Ji_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_pxl1r00e, HV_BINOP_POW, 0, m, &cBinop_pxl1r00e_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pxl1r00e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EpgvcOxr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_lwPdJADo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_g7UZNjrZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_pJL7xXKE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_nc4oYo5f_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_HeWdu7Fi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qiY788Or, 0, m, &cIf_qiY788Or_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nc4oYo5f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qiY788Or, 1, m, &cIf_qiY788Or_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aHANnk5y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_lwPdJADo_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kKEsfyMR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_EpgvcOxr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_g7UZNjrZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pxl1r00e, HV_BINOP_POW, 1, m, &cBinop_pxl1r00e_sendMessage);
  cMsg_Vmt9h2Ji_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_uGoxyvne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fxyvbjya, HV_BINOP_MULTIPLY, 0, m, &cBinop_Fxyvbjya_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Na0IshWs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VWTpPtOw_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_VWTpPtOw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_U65qXW8i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_Fxyvbjya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_xKYOcgTi_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aRKRfXme_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fxyvbjya, HV_BINOP_MULTIPLY, 1, m, &cBinop_Fxyvbjya_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_U65qXW8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_aRKRfXme_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xKYOcgTi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_TaRfdtZ0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TaRfdtZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_XiKUpc3d_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_V3kRjJzs, m);
}

void Heavy_WSTD_DL3Y::cBinop_XiKUpc3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_uQztaIh0, m);
}

void Heavy_WSTD_DL3Y::cMsg_EpgvcOxr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_tMVOPUib_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tMVOPUib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_5S5vOXMH, m);
}

void Heavy_WSTD_DL3Y::sEnv_DFJIEQRx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RJjJyLpc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2crfKJLy_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_aQN6Rz0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_MCy4x35K_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_5MAfZeuT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_1I9fpo25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VMAXN0P1, HV_BINOP_POW, 0, m, &cBinop_VMAXN0P1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VMAXN0P1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dwGpONDe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_ZF269FPQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_0yHcHwTE_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_2crfKJLy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aQN6Rz0x, 0, m, &cIf_aQN6Rz0x_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_RJjJyLpc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_GLJb2X9P_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GLJb2X9P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aQN6Rz0x, 1, m, &cIf_aQN6Rz0x_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_5MAfZeuT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_ZF269FPQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MCy4x35K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_dwGpONDe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_0yHcHwTE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VMAXN0P1, HV_BINOP_POW, 1, m, &cBinop_VMAXN0P1_sendMessage);
  cMsg_1I9fpo25_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_nxrxgwKC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OnWefO3P, HV_BINOP_MULTIPLY, 0, m, &cBinop_OnWefO3P_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kaWdcntb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_shg6BlOn_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_shg6BlOn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MaUzS1sv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_OnWefO3P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_g2bCWJSt_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NfwRO60G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OnWefO3P, HV_BINOP_MULTIPLY, 1, m, &cBinop_OnWefO3P_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_MaUzS1sv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_NfwRO60G_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_g2bCWJSt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_A6vG5PCB_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_A6vG5PCB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ErqJYsB2_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_RI08X2CC, m);
}

void Heavy_WSTD_DL3Y::cBinop_ErqJYsB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_O0z3mHw6, m);
}

void Heavy_WSTD_DL3Y::cMsg_dwGpONDe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_tMULZKKq_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_tMULZKKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_x1DmdgrR, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_FQeHLIp5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8ojyUrPu, 0, m, &cSlice_8ojyUrPu_sendMessage);
      break;
    }
    default: {
      cSwitchcase_3vhU3qu2_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_8ojyUrPu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hZRrdASt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hZRrdASt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_IovWFZpH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hZRrdASt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_hZRrdASt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_r08WcwYK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_GCpuCcuM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9QOc6z3U_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_9QOc6z3U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_i9txsGnQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_q550ckdZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_q550ckdZ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1EbdII70, 0, m, &cDelay_1EbdII70_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_q550ckdZ, 0, m, &cDelay_q550ckdZ_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ZOw8edq6, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_1EbdII70_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1EbdII70, m);
  cMsg_VcI4XQlE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_WJebBUiW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_zkoamu7j_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_VvEoF05V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wcG3Q952_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_l0IncrFz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TowsStWu_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_q550ckdZ, 2, m, &cDelay_q550ckdZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_azLLP6ou_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wcG3Q952_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_l0IncrFz, 0, m, &hTable_l0IncrFz_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_i9txsGnQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_VvEoF05V_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_VcI4XQlE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_l0IncrFz, 0, m, &hTable_l0IncrFz_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_azLLP6ou_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_q550ckdZ, 0, m, &cDelay_q550ckdZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_TowsStWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_1EbdII70, 2, m, &cDelay_1EbdII70_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_zkoamu7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ZOw8edq6, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_OIHZAbFg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K4tjGFvd, HV_BINOP_SUBTRACT, 0, m, &cBinop_K4tjGFvd_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_R1rAXzua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ySrJyMMj_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_ySrJyMMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_19vta46x_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_014zaDta_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SVSPsZPZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_m6jKyC4p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_m6jKyC4p, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3tiRgNAW, 0, m, &cDelay_3tiRgNAW_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_HEZUet5I, 0, m, &sTabread_HEZUet5I_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_3tiRgNAW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3tiRgNAW, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_HEZUet5I, 0, m, &sTabread_HEZUet5I_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3tiRgNAW, 0, m, &cDelay_3tiRgNAW_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_HEZUet5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_YxLkTspv, HV_BINOP_SUBTRACT, 0, m, &cBinop_YxLkTspv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_MvexPnO7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XsBiMf7l, HV_BINOP_MAX, 0, m, &cBinop_XsBiMf7l_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_19vta46x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MvexPnO7, HV_BINOP_MULTIPLY, 0, m, &cBinop_MvexPnO7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_K4tjGFvd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w9oR1QK2_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_HEZUet5I, 0, m, &sTabread_HEZUet5I_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Hgb7S8nG_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_q8foFpV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YxLkTspv, HV_BINOP_SUBTRACT, 1, m, &cBinop_YxLkTspv_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3tiRgNAW, 2, m, &cDelay_3tiRgNAW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SVSPsZPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_q8foFpV5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_w9oR1QK2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_m6jKyC4p, 0, m, &cDelay_m6jKyC4p_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3tiRgNAW, 0, m, &cDelay_3tiRgNAW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RJVG7joa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_XsBiMf7l, HV_BINOP_MAX, 1, m, &cBinop_XsBiMf7l_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_XsBiMf7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K4tjGFvd, HV_BINOP_SUBTRACT, 1, m, &cBinop_K4tjGFvd_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Hgb7S8nG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_m6jKyC4p, 0, m, &cDelay_m6jKyC4p_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EpUNLIsn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_m6jKyC4p, 2, m, &cDelay_m6jKyC4p_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_YxLkTspv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_EpUNLIsn_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_OG4C8SbF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_014zaDta, 0, m, &cVar_014zaDta_sendMessage);
  cMsg_R1rAXzua_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_OIHZAbFg, 0, m, &cTabhead_OIHZAbFg_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_kiS4g0Cc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wedoZA0b_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_wedoZA0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_p2hy4PlC_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_ePmoaHbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ePmoaHbq, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hbPEdna8, 0, m, &cDelay_hbPEdna8_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ePmoaHbq, 0, m, &cDelay_ePmoaHbq_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_le5aNwMb, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_hbPEdna8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hbPEdna8, m);
  cMsg_visSFFwK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_1z3EBQaP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_IEbaTIsU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_52VG2F5H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bsWGz04L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_QNUaIDyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fIKv5fY0_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ePmoaHbq, 2, m, &cDelay_ePmoaHbq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ECCTzLPD_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_bsWGz04L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_QNUaIDyf, 0, m, &hTable_QNUaIDyf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_p2hy4PlC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_52VG2F5H_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_visSFFwK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_QNUaIDyf, 0, m, &hTable_QNUaIDyf_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_ECCTzLPD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ePmoaHbq, 0, m, &cDelay_ePmoaHbq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_fIKv5fY0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_hbPEdna8, 2, m, &cDelay_hbPEdna8_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_IEbaTIsU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_le5aNwMb, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_jMesxc8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eKjZ7Hq6, HV_BINOP_SUBTRACT, 0, m, &cBinop_eKjZ7Hq6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Qcoj6j5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XX19nOmt_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_XX19nOmt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_W8vRCgdE_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_WRJ2OwTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KI3XrP1i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_zVsjffV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zVsjffV0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_USpfw6Pp, 0, m, &cDelay_USpfw6Pp_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_SSFbyvXA, 0, m, &sTabread_SSFbyvXA_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_USpfw6Pp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_USpfw6Pp, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_SSFbyvXA, 0, m, &sTabread_SSFbyvXA_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_USpfw6Pp, 0, m, &cDelay_USpfw6Pp_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_SSFbyvXA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_Gi16lz0U, HV_BINOP_SUBTRACT, 0, m, &cBinop_Gi16lz0U_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_1W7dH990_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iBkrQsoe, HV_BINOP_MAX, 0, m, &cBinop_iBkrQsoe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_W8vRCgdE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1W7dH990, HV_BINOP_MULTIPLY, 0, m, &cBinop_1W7dH990_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eKjZ7Hq6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b3XFRCix_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_SSFbyvXA, 0, m, &sTabread_SSFbyvXA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lxEIdHS5_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_p0DEJZ2l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gi16lz0U, HV_BINOP_SUBTRACT, 1, m, &cBinop_Gi16lz0U_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_USpfw6Pp, 2, m, &cDelay_USpfw6Pp_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_KI3XrP1i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_p0DEJZ2l_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_b3XFRCix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zVsjffV0, 0, m, &cDelay_zVsjffV0_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_USpfw6Pp, 0, m, &cDelay_USpfw6Pp_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ng0oCCmt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_iBkrQsoe, HV_BINOP_MAX, 1, m, &cBinop_iBkrQsoe_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iBkrQsoe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eKjZ7Hq6, HV_BINOP_SUBTRACT, 1, m, &cBinop_eKjZ7Hq6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_lxEIdHS5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zVsjffV0, 0, m, &cDelay_zVsjffV0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_04v6sdEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zVsjffV0, 2, m, &cDelay_zVsjffV0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Gi16lz0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_04v6sdEZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yvhM3vYF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WRJ2OwTY, 0, m, &cVar_WRJ2OwTY_sendMessage);
  cMsg_Qcoj6j5c_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_jMesxc8B, 0, m, &cTabhead_jMesxc8B_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cQiUGLZN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_o0zXKTjv, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_U0PDK9WX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_S3bp2jJd, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_IKrRcKsO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_60cscanS, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_BMeDBwOk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8iunXTgk, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_FymdXutK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xWgem0k7, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_kMk6IVgp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LAEdQWtq, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_eVU2M2X3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tDhPsPIX, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_TE6C3qXt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7pOtSAQi, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cSwitchcase_XImPLQcm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Y4dPGUJj, 0, m, &cSlice_Y4dPGUJj_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_Y4dPGUJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_3o1DPpN6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_3o1DPpN6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_jBOqt7RQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3o1DPpN6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_3o1DPpN6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fWf1QHfQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_2UiQd2F4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_hmBfsXXD, 0, m, &cSlice_hmBfsXXD_sendMessage);
      break;
    }
    default: {
      cSwitchcase_phvBT17P_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_hmBfsXXD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7XUWUtTb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7XUWUtTb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_rlxLNri8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7XUWUtTb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_7XUWUtTb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kGJXrN4H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_BkcxG9KC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_HucTGjmQ, 0, m, &cSlice_HucTGjmQ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_XImPLQcm_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_HucTGjmQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_RfxpNYoo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_RfxpNYoo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_2qQrIAiR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RfxpNYoo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_RfxpNYoo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AkCHELWB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_AXNauAX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_x2qiVTKm_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_x2qiVTKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_teHLDGPU_sendMessage);
}

void Heavy_WSTD_DL3Y::cUnop_1z2KF6PA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EWHSzNc9_sendMessage(_c, 0, m);
  cMsg_LxkjvRrJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cUnop_EwF1pEkQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oIxB28H8_sendMessage(_c, 0, m);
  cMsg_k8xPVsyA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_teHLDGPU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_qa9T5XVS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_qa9T5XVS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_p1XTzkti_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1hfJgUS1_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_1hfJgUS1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uUgDD3zq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_p1XTzkti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_uiw1f27U_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_uiw1f27U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_FXalIq0l_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uUgDD3zq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_MwyoBBfv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MwyoBBfv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_a4vXQ3ly_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FXalIq0l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_1z2KF6PA_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_a4vXQ3ly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_EwF1pEkQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_3OGoGW35_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_k4TcS3Yo_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_k4TcS3Yo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_Pr2ZB4ZW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Pr2ZB4ZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_LbkI5dCV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_LbkI5dCV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kQo5uenu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aQWz2GKD_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_aQWz2GKD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7PX9WQGV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_kQo5uenu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_wYdTWndR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wYdTWndR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_AKdO0a20_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_7PX9WQGV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_zofLpN01_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_zofLpN01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Jjxw1yrS_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Jjxw1yrS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wLKAzHSI_sendMessage(_c, 0, m);
  cMsg_gbUDGGF0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_AKdO0a20_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5DkSY0wI_sendMessage(_c, 0, m);
  cMsg_baFyO6Td_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_NDCcp9B8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Q3JRPzsk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Q3JRPzsk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_99P10uR6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_bIgiZqJu_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_jN81pU6p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_VFMWEotf_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uuB7BIuS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_XLkoDI94_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_XLkoDI94_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ys3c3J3X, HV_BINOP_DIVIDE, 1, m, &cBinop_ys3c3J3X_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_99P10uR6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Tn8TfVbx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Tn8TfVbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ItvRIWgD, m);
}

void Heavy_WSTD_DL3Y::cMsg_B8kCdiOo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_541T69mn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_541T69mn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_NDCcp9B8_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_bIgiZqJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_CaPtF90q, m);
}

void Heavy_WSTD_DL3Y::cBinop_VFMWEotf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_REa6X1Bj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_REa6X1Bj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ys3c3J3X, HV_BINOP_DIVIDE, 0, m, &cBinop_ys3c3J3X_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ys3c3J3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_B8kCdiOo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_uQ2YPAdu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_SudLQ0bW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_SudLQ0bW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_i0ZHwpSH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_EU7EuZnt_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_AbjLWBiB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_ImbJJvPQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Fo0YlVMp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fMmbjZOn_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_fMmbjZOn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OLkEK77x, HV_BINOP_DIVIDE, 1, m, &cBinop_OLkEK77x_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_i0ZHwpSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_q99PLcAW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_q99PLcAW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_XWmMfFw8, m);
}

void Heavy_WSTD_DL3Y::cMsg_nTyFysZx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_VVCowLpj_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VVCowLpj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_uQ2YPAdu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_EU7EuZnt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_2V1QJf8D, m);
}

void Heavy_WSTD_DL3Y::cBinop_ImbJJvPQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_q1z4kTZE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_q1z4kTZE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OLkEK77x, HV_BINOP_DIVIDE, 0, m, &cBinop_OLkEK77x_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_OLkEK77x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nTyFysZx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_JzFgnREq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nDiR83wp, HV_BINOP_MULTIPLY, 0, m, &cBinop_nDiR83wp_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_2b26EeJ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1FH0Rlfd_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_1FH0Rlfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dPzkKCqs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_nDiR83wp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_30frBq8W_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_V7KPhXSX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nDiR83wp, HV_BINOP_MULTIPLY, 1, m, &cBinop_nDiR83wp_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dPzkKCqs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_V7KPhXSX_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_30frBq8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_nDWWK01o_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_nDWWK01o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_pZkoNKD3_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_cXKK7fEd, m);
}

void Heavy_WSTD_DL3Y::cBinop_pZkoNKD3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ea4D5TlJ, m);
}

void Heavy_WSTD_DL3Y::cVar_5fzM89CI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z697gQG0, HV_BINOP_MULTIPLY, 0, m, &cBinop_z697gQG0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_FlUGxX8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_elKBZYnT_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_elKBZYnT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aqHHMULS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_z697gQG0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_PNmbPLR0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_cE7VrZxn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z697gQG0, HV_BINOP_MULTIPLY, 1, m, &cBinop_z697gQG0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_aqHHMULS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_cE7VrZxn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_PNmbPLR0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_NALGcoj0_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NALGcoj0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_UEL880I7_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_tHwzBFle, m);
}

void Heavy_WSTD_DL3Y::cBinop_UEL880I7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ygmG6B2l, m);
}

void Heavy_WSTD_DL3Y::sEnv_Gm5Etzfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M03If6iE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Wetd02pS_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_PTjcZFqb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_t9dN8AWs_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_k1suIQFP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_CmNGgq9p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6ba0fGE7, HV_BINOP_POW, 0, m, &cBinop_6ba0fGE7_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_6ba0fGE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LQeSGpXH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_mSEkd9gp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_W2jWoWdK_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Wetd02pS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PTjcZFqb, 0, m, &cIf_PTjcZFqb_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_M03If6iE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_UxgPcKxf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_UxgPcKxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PTjcZFqb, 1, m, &cIf_PTjcZFqb_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_k1suIQFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_mSEkd9gp_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_t9dN8AWs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_LQeSGpXH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_W2jWoWdK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6ba0fGE7, HV_BINOP_POW, 1, m, &cBinop_6ba0fGE7_sendMessage);
  cMsg_CmNGgq9p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_bs9lxL49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SGIiRRvL, HV_BINOP_MULTIPLY, 0, m, &cBinop_SGIiRRvL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_dpI2D8GJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_I4kqOH7d_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_I4kqOH7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2vcbgA0Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_SGIiRRvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_daukuRlx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wAI1Dt2y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SGIiRRvL, HV_BINOP_MULTIPLY, 1, m, &cBinop_SGIiRRvL_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_2vcbgA0Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_wAI1Dt2y_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_daukuRlx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_CXN5hlpx_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_CXN5hlpx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_h4S5GeI4_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_iKvg9tEB, m);
}

void Heavy_WSTD_DL3Y::cBinop_h4S5GeI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_D08FwTfS, m);
}

void Heavy_WSTD_DL3Y::cMsg_LQeSGpXH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_hj5tKY50_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_hj5tKY50_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_2FELjDFx, m);
}

void Heavy_WSTD_DL3Y::sEnv_LcphiCwq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aqy3QUPO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vWiR3dhs_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_PXkCSibE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_APE24anx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_L7iucybO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cMsg_76boK9eQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Kks8ijIU, HV_BINOP_POW, 0, m, &cBinop_Kks8ijIU_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Kks8ijIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5u1tqmX0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_mfb1fQiA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_WUmBI57d_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vWiR3dhs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PXkCSibE, 0, m, &cIf_PXkCSibE_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_aqy3QUPO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_l3NPMTaw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_l3NPMTaw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PXkCSibE, 1, m, &cIf_PXkCSibE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_L7iucybO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_mfb1fQiA_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_APE24anx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_5u1tqmX0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_WUmBI57d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Kks8ijIU, HV_BINOP_POW, 1, m, &cBinop_Kks8ijIU_sendMessage);
  cMsg_76boK9eQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cVar_qYNayVPB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XtnGdl5o, HV_BINOP_MULTIPLY, 0, m, &cBinop_XtnGdl5o_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_s3hRY2Zi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7hwnpL1A_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_7hwnpL1A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oAg2jyMW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_XtnGdl5o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_gceuDxjE_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_NChD3JgW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XtnGdl5o, HV_BINOP_MULTIPLY, 1, m, &cBinop_XtnGdl5o_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_oAg2jyMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_NChD3JgW_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_gceuDxjE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_myA7zCLg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_myA7zCLg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_On0noCuo_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_9YTKvYQ5, m);
}

void Heavy_WSTD_DL3Y::cBinop_On0noCuo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_09yBpt3P, m);
}

void Heavy_WSTD_DL3Y::cMsg_5u1tqmX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_FW6uRgkH_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_FW6uRgkH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_HpeargDJ, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_phvBT17P_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jHFtejUC, 0, m, &cSlice_jHFtejUC_sendMessage);
      break;
    }
    default: {
      cSwitchcase_BkcxG9KC_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_jHFtejUC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_LQt3Rub3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_LQt3Rub3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_HcMVUmml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LQt3Rub3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSend_LQt3Rub3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nleWyDXn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cMsg_erxnto1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gpncQdSF_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_gpncQdSF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_yfVJnE45_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_zB4l4ZFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zB4l4ZFN, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UakUDZC6, 0, m, &cDelay_UakUDZC6_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zB4l4ZFN, 0, m, &cDelay_zB4l4ZFN_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_O636VV2I, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_UakUDZC6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UakUDZC6, m);
  cMsg_nlZVOR0O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_RCEMpvq3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ieLIAyMK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_3E78V1Te_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ReI8EuuJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_H0dtbbzM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_debg9wuH_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zB4l4ZFN, 2, m, &cDelay_zB4l4ZFN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QnmOib4F_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ReI8EuuJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_H0dtbbzM, 0, m, &hTable_H0dtbbzM_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_yfVJnE45_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_3E78V1Te_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nlZVOR0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_H0dtbbzM, 0, m, &hTable_H0dtbbzM_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_QnmOib4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zB4l4ZFN, 0, m, &cDelay_zB4l4ZFN_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_debg9wuH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_UakUDZC6, 2, m, &cDelay_UakUDZC6_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ieLIAyMK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_O636VV2I, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_OnklvKOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GCx5w7Db, HV_BINOP_SUBTRACT, 0, m, &cBinop_GCx5w7Db_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_DTuWoS3J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_J0xAYrKB_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_J0xAYrKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_GBqsiNqh_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_oYKO7Gfk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FlUCBjDx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_MWOwftR3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MWOwftR3, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oLdt0x4U, 0, m, &cDelay_oLdt0x4U_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_14kgdxnh, 0, m, &sTabread_14kgdxnh_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_oLdt0x4U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oLdt0x4U, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_14kgdxnh, 0, m, &sTabread_14kgdxnh_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oLdt0x4U, 0, m, &cDelay_oLdt0x4U_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_14kgdxnh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_HpJ8NsvE, HV_BINOP_SUBTRACT, 0, m, &cBinop_HpJ8NsvE_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_8nkUUida_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ViCJyBvh, HV_BINOP_MAX, 0, m, &cBinop_ViCJyBvh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GBqsiNqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8nkUUida, HV_BINOP_MULTIPLY, 0, m, &cBinop_8nkUUida_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GCx5w7Db_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2BRF6vN1_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_14kgdxnh, 0, m, &sTabread_14kgdxnh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jsj8VnGX_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_1IoRyvIZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HpJ8NsvE, HV_BINOP_SUBTRACT, 1, m, &cBinop_HpJ8NsvE_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oLdt0x4U, 2, m, &cDelay_oLdt0x4U_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_FlUCBjDx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1IoRyvIZ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_2BRF6vN1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_MWOwftR3, 0, m, &cDelay_MWOwftR3_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oLdt0x4U, 0, m, &cDelay_oLdt0x4U_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_FhuyjADM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_ViCJyBvh, HV_BINOP_MAX, 1, m, &cBinop_ViCJyBvh_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_ViCJyBvh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GCx5w7Db, HV_BINOP_SUBTRACT, 1, m, &cBinop_GCx5w7Db_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_jsj8VnGX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MWOwftR3, 0, m, &cDelay_MWOwftR3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_aYeoxjDE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MWOwftR3, 2, m, &cDelay_MWOwftR3_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HpJ8NsvE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_aYeoxjDE_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3LlMwijB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oYKO7Gfk, 0, m, &cVar_oYKO7Gfk_sendMessage);
  cMsg_DTuWoS3J_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_OnklvKOT, 0, m, &cTabhead_OnklvKOT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_aRt3MfKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lQ6vESlt_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_lQ6vESlt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_iqgCMA45_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_PPyLO5LO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PPyLO5LO, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_eyGQl0fW, 0, m, &cDelay_eyGQl0fW_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PPyLO5LO, 0, m, &cDelay_PPyLO5LO_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_No5W9kPu, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cDelay_eyGQl0fW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_eyGQl0fW, m);
  cMsg_nUjAxiHr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cSwitchcase_RxNxQbTU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_aqXydIO4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cBinop_W7FT0Pt2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Yuiiwp4t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::hTable_7IyuYJGc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b3xD7Aqv_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PPyLO5LO, 2, m, &cDelay_PPyLO5LO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8Go2em28_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Yuiiwp4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_7IyuYJGc, 0, m, &hTable_7IyuYJGc_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iqgCMA45_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_W7FT0Pt2_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nUjAxiHr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_7IyuYJGc, 0, m, &hTable_7IyuYJGc_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8Go2em28_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PPyLO5LO, 0, m, &cDelay_PPyLO5LO_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_b3xD7Aqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_eyGQl0fW, 2, m, &cDelay_eyGQl0fW_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_aqXydIO4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_No5W9kPu, 1, m, NULL);
}

void Heavy_WSTD_DL3Y::cTabhead_NgciWd3p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_liegG1R5, HV_BINOP_SUBTRACT, 0, m, &cBinop_liegG1R5_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1zklYuTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lJbN3nrl_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_lJbN3nrl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_GkupAvYF_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_aPZqDUFe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uHFpRGmi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cDelay_6ixuekj4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6ixuekj4, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2Ktd88EV, 0, m, &cDelay_2Ktd88EV_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_dOrlPuKQ, 0, m, &sTabread_dOrlPuKQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cDelay_2Ktd88EV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2Ktd88EV, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_dOrlPuKQ, 0, m, &sTabread_dOrlPuKQ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2Ktd88EV, 0, m, &cDelay_2Ktd88EV_sendMessage);
}

void Heavy_WSTD_DL3Y::sTabread_dOrlPuKQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_oH3og9jz, HV_BINOP_SUBTRACT, 0, m, &cBinop_oH3og9jz_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cBinop_cBaBZXTR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Pc6FFFMw, HV_BINOP_MAX, 0, m, &cBinop_Pc6FFFMw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_GkupAvYF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cBaBZXTR, HV_BINOP_MULTIPLY, 0, m, &cBinop_cBaBZXTR_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_liegG1R5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8aj8Byn7_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_dOrlPuKQ, 0, m, &sTabread_dOrlPuKQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xUsPj7Pp_sendMessage);
}

void Heavy_WSTD_DL3Y::cSystem_5YhqMYdT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oH3og9jz, HV_BINOP_SUBTRACT, 1, m, &cBinop_oH3og9jz_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2Ktd88EV, 2, m, &cDelay_2Ktd88EV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_uHFpRGmi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_5YhqMYdT_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8aj8Byn7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_6ixuekj4, 0, m, &cDelay_6ixuekj4_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2Ktd88EV, 0, m, &cDelay_2Ktd88EV_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_8BTo59T0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_Pc6FFFMw, HV_BINOP_MAX, 1, m, &cBinop_Pc6FFFMw_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Pc6FFFMw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_liegG1R5, HV_BINOP_SUBTRACT, 1, m, &cBinop_liegG1R5_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_xUsPj7Pp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6ixuekj4, 0, m, &cDelay_6ixuekj4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_VWhp9UYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6ixuekj4, 2, m, &cDelay_6ixuekj4_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oH3og9jz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_VWhp9UYm_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_DZxDG6Vq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aPZqDUFe, 0, m, &cVar_aPZqDUFe_sendMessage);
  cMsg_1zklYuTZ_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_NgciWd3p, 0, m, &cTabhead_NgciWd3p_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_EWHSzNc9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3AjZ855b, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_oIxB28H8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sjnrv9ru, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_k8xPVsyA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZWKg5aZO, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_LxkjvRrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KSjAeUBA, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_baFyO6Td_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ajm2fVNm, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_wLKAzHSI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_P8N7HRta, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_5DkSY0wI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IasK3k7S, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_gbUDGGF0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zo6ZxP0q, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cVar_VvcSrGlx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7CRjm1dw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_mnn9tqKS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Lnd4MYyT_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7CRjm1dw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VvcSrGlx, 1, m, &cVar_VvcSrGlx_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_K61ULp54_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_Z1bOiHrq, 0, m, &cVar_Z1bOiHrq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_g7Cymyuj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_Z1bOiHrq, 0, m, &cVar_Z1bOiHrq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_wBptCiL9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_g7Cymyuj, 0, m, &cIf_g7Cymyuj_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_MAYqDEZk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K61ULp54, 0, m, &cIf_K61ULp54_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_2UWh6rW1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_spOuVc3F_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9Aku98Oh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Ts4efWgN_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_spOuVc3F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2UWh6rW1, 1, m, &cVar_2UWh6rW1_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_yQGhBQeR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_JRRPP6HI, 0, m, &cVar_JRRPP6HI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_5hj4MkKl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_JRRPP6HI, 0, m, &cVar_JRRPP6HI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_bDEEkYjS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5hj4MkKl, 0, m, &cIf_5hj4MkKl_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_g9M4JmQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yQGhBQeR, 0, m, &cIf_yQGhBQeR_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_kajGFQeT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eQgRuESM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oN1pONJt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_7mcfUPQ5_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_eQgRuESM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kajGFQeT, 1, m, &cVar_kajGFQeT_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_f2np9MJg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_ajVwMvq4, 0, m, &cVar_ajVwMvq4_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cIf_dhn8p6XR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_ajVwMvq4, 0, m, &cVar_ajVwMvq4_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_zunxaUUd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dhn8p6XR, 0, m, &cIf_dhn8p6XR_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_T36cu6At_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_f2np9MJg, 0, m, &cIf_f2np9MJg_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_S174Ast0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KBbYgMq3, HV_BINOP_DIVIDE, 0, m, &cBinop_KBbYgMq3_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_QkDdz1zO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jIU5sHgG, HV_BINOP_MULTIPLY, 1, m, &cBinop_jIU5sHgG_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_KLt8b3sl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_siliQPjb, 0, m, &cSlice_siliQPjb_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_75sbklFL, 0, m, &cSlice_75sbklFL_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3waN1bu4_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kYJNvPQL_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_siliQPjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_uyAVZCm9, 0, m, &cVar_uyAVZCm9_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_uyAVZCm9, 0, m, &cVar_uyAVZCm9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_75sbklFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_2RTJVtRg, HV_BINOP_NEQ, 1, m, &cBinop_2RTJVtRg_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_uyAVZCm9, 1, m, &cVar_uyAVZCm9_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_2RTJVtRg, HV_BINOP_NEQ, 1, m, &cBinop_2RTJVtRg_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_uyAVZCm9, 1, m, &cVar_uyAVZCm9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_uyAVZCm9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_4GGoHLMJ_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_lxFA50t2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PLNFplBP_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HjiTdfGp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_HjiTdfGp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uyAVZCm9, 0, m, &cVar_uyAVZCm9_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_PLNFplBP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2RTJVtRg, HV_BINOP_NEQ, 1, m, &cBinop_2RTJVtRg_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_2RTJVtRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lxFA50t2, 1, m, &cIf_lxFA50t2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_kYJNvPQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lxFA50t2, 0, m, &cIf_lxFA50t2_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_3waN1bu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2RTJVtRg, HV_BINOP_NEQ, 0, m, &cBinop_2RTJVtRg_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_YTznyMpd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_q4Achrxu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5wjfHCUT_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_fZ0ELLE4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CrdY5Ktp_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VCpGI8Ao_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RW95MnDI_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ga0p8tzm_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_85EKuZcx_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Pw19mLiw_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PnyHBGrO_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7pLfqFkY_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ir1lBy3t_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wl1yvHMu_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BO0WFIsw_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VmEyXJY1_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zdeC7KKT_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_CrdY5Ktp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wLzLnviD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_VCpGI8Ao_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cP2ajDvO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_RW95MnDI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yi0BCmHu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Ga0p8tzm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YtCTFdVk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_85EKuZcx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vDYZ4Vh6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Pw19mLiw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HdbXcncC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_PnyHBGrO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5wueuQFC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_7pLfqFkY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZylukLcy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_ir1lBy3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1sFYode9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_wl1yvHMu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GRwBWwEZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_BO0WFIsw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_foqZhXeP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_VmEyXJY1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SmWnN5qG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_zdeC7KKT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ln1wOw6l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_KBbYgMq3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jIU5sHgG, HV_BINOP_MULTIPLY, 0, m, &cBinop_jIU5sHgG_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_jIU5sHgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_KLt8b3sl_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_5wjfHCUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_S174Ast0, 0, m, &cVar_S174Ast0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QkDdz1zO, 0, m, &cVar_QkDdz1zO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_q4Achrxu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KBbYgMq3, HV_BINOP_DIVIDE, 1, m, &cBinop_KBbYgMq3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_8wOnrfgu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QkDdz1zO, 0, m, &cVar_QkDdz1zO_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_Mia7OAdQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_S174Ast0, 0, m, &cVar_S174Ast0_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_wLzLnviD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8wOnrfgu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mia7OAdQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cP2ajDvO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8wOnrfgu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mia7OAdQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_yi0BCmHu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8wOnrfgu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mia7OAdQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_YtCTFdVk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8wOnrfgu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mia7OAdQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_vDYZ4Vh6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8wOnrfgu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mia7OAdQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_HdbXcncC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8wOnrfgu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mia7OAdQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_5wueuQFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8wOnrfgu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mia7OAdQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZylukLcy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8wOnrfgu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mia7OAdQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_1sFYode9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8wOnrfgu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mia7OAdQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_GRwBWwEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8wOnrfgu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mia7OAdQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_foqZhXeP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8wOnrfgu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mia7OAdQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_SmWnN5qG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8wOnrfgu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mia7OAdQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ln1wOw6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8wOnrfgu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mia7OAdQ_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_Cmf7BGVW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bd0dPcB6, HV_BINOP_DIVIDE, 0, m, &cBinop_bd0dPcB6_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_H77wVM5Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HbFSvobf, HV_BINOP_MULTIPLY, 1, m, &cBinop_HbFSvobf_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_Pcuck0Kb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Yl8aZ9sI, 0, m, &cSlice_Yl8aZ9sI_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zVEhcqNk, 0, m, &cSlice_zVEhcqNk_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tChh91hi_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rCOy0JZT_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_Yl8aZ9sI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_GR9Lnaa7, 0, m, &cVar_GR9Lnaa7_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_GR9Lnaa7, 0, m, &cVar_GR9Lnaa7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_zVEhcqNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_7iZT1P2a, HV_BINOP_NEQ, 1, m, &cBinop_7iZT1P2a_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_GR9Lnaa7, 1, m, &cVar_GR9Lnaa7_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_7iZT1P2a, HV_BINOP_NEQ, 1, m, &cBinop_7iZT1P2a_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_GR9Lnaa7, 1, m, &cVar_GR9Lnaa7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_GR9Lnaa7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_JEibIVtM_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_fhOYslsN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rjJUPtx0_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZiYSq835_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_ZiYSq835_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GR9Lnaa7, 0, m, &cVar_GR9Lnaa7_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rjJUPtx0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7iZT1P2a, HV_BINOP_NEQ, 1, m, &cBinop_7iZT1P2a_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7iZT1P2a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fhOYslsN, 1, m, &cIf_fhOYslsN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_rCOy0JZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fhOYslsN, 0, m, &cIf_fhOYslsN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_tChh91hi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7iZT1P2a, HV_BINOP_NEQ, 0, m, &cBinop_7iZT1P2a_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_0x7IhzAj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mT1n1YJv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_B3Iv7dE1_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_JA0lTpzw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LXKbcpD1_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_g13kiC0M_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WW2vZUp6_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s3Brrk5Z_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MjSuNFud_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jOFxjG4Z_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_49d4cFYG_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_34IroBIg_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IieIHURJ_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_soccjY6l_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qRK543xM_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vuSsunOT_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CB2rGqT6_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_LXKbcpD1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lFx92rkX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_g13kiC0M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KDuucogJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_WW2vZUp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PPsqPfn5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_s3Brrk5Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ScHlKEjt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_MjSuNFud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QIaTDQ9m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_jOFxjG4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OMSiO3D2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_49d4cFYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yYxeJ8W2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_34IroBIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UmnGiB1L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_IieIHURJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_14uHRr46_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_soccjY6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pXJsgOrS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_qRK543xM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sUvNmfPu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_vuSsunOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cNgVJcIO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_CB2rGqT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lWaDfkdu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_bd0dPcB6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HbFSvobf, HV_BINOP_MULTIPLY, 0, m, &cBinop_HbFSvobf_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_HbFSvobf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Pcuck0Kb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_B3Iv7dE1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Cmf7BGVW, 0, m, &cVar_Cmf7BGVW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_H77wVM5Y, 0, m, &cVar_H77wVM5Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_mT1n1YJv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bd0dPcB6, HV_BINOP_DIVIDE, 1, m, &cBinop_bd0dPcB6_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_lvb3lj4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Cmf7BGVW, 0, m, &cVar_Cmf7BGVW_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_2Pekobxv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_H77wVM5Y, 0, m, &cVar_H77wVM5Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lFx92rkX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2Pekobxv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lvb3lj4R_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_KDuucogJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2Pekobxv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lvb3lj4R_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_PPsqPfn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2Pekobxv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lvb3lj4R_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ScHlKEjt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2Pekobxv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lvb3lj4R_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_QIaTDQ9m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2Pekobxv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lvb3lj4R_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OMSiO3D2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2Pekobxv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lvb3lj4R_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_yYxeJ8W2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2Pekobxv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lvb3lj4R_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UmnGiB1L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2Pekobxv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lvb3lj4R_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_14uHRr46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2Pekobxv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lvb3lj4R_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_pXJsgOrS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2Pekobxv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lvb3lj4R_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_sUvNmfPu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2Pekobxv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lvb3lj4R_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_cNgVJcIO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2Pekobxv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lvb3lj4R_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_lWaDfkdu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2Pekobxv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lvb3lj4R_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_DxR2qksN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uWwJ6KeI, HV_BINOP_DIVIDE, 0, m, &cBinop_uWwJ6KeI_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_hUXH3ocq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dMMJVfZC, HV_BINOP_MULTIPLY, 1, m, &cBinop_dMMJVfZC_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_FDj526pU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_M0MegyC4, 0, m, &cSlice_M0MegyC4_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_faX10WYN, 0, m, &cSlice_faX10WYN_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kwGOTTCq_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VelyoiNp_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cSlice_M0MegyC4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_duYsdInu, 0, m, &cVar_duYsdInu_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_duYsdInu, 0, m, &cVar_duYsdInu_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cSlice_faX10WYN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_xkeSvq1t, HV_BINOP_NEQ, 1, m, &cBinop_xkeSvq1t_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_duYsdInu, 1, m, &cVar_duYsdInu_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_xkeSvq1t, HV_BINOP_NEQ, 1, m, &cBinop_xkeSvq1t_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_duYsdInu, 1, m, &cVar_duYsdInu_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cVar_duYsdInu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_BUfxhUgA_sendMessage);
}

void Heavy_WSTD_DL3Y::cIf_Z3riFqS3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wN6z6VFr_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5ENvsYkR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DL3Y::cCast_5ENvsYkR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_duYsdInu, 0, m, &cVar_duYsdInu_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_wN6z6VFr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xkeSvq1t, HV_BINOP_NEQ, 1, m, &cBinop_xkeSvq1t_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_xkeSvq1t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Z3riFqS3, 1, m, &cIf_Z3riFqS3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_VelyoiNp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Z3riFqS3, 0, m, &cIf_Z3riFqS3_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_kwGOTTCq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xkeSvq1t, HV_BINOP_NEQ, 0, m, &cBinop_xkeSvq1t_sendMessage);
}

void Heavy_WSTD_DL3Y::cVar_dm86fs1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4MG70CaH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SrgoITAz_sendMessage);
}

void Heavy_WSTD_DL3Y::cSwitchcase_k6zXXvvi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eTDB2Zpo_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PpqkYMG1_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W6HAjK5E_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Kt36v7K5_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AwHOo93o_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bBccbmXc_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jQQcngNi_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7zRoEEv5_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iwAguiSp_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mneevg3m_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qsjRutOQ_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O4clltrd_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qain9yZn_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DL3Y::cCast_eTDB2Zpo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nTlrm7PZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_PpqkYMG1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oF4mLzUy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_W6HAjK5E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6fc5ktYR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_Kt36v7K5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ANzGNE8V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_AwHOo93o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RhBo1231_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_bBccbmXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_suy4RFaj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_jQQcngNi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_40f1c7Ql_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_7zRoEEv5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZlSZI1cY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_iwAguiSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OHvtoiql_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_mneevg3m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ijDU9kIb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_qsjRutOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IEmCV5bP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_O4clltrd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZfbWM0FV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cCast_qain9yZn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rX0eTyuB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cBinop_uWwJ6KeI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dMMJVfZC, HV_BINOP_MULTIPLY, 0, m, &cBinop_dMMJVfZC_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_dMMJVfZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_FDj526pU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cCast_4MG70CaH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uWwJ6KeI, HV_BINOP_DIVIDE, 1, m, &cBinop_uWwJ6KeI_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_SrgoITAz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DxR2qksN, 0, m, &cVar_DxR2qksN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hUXH3ocq, 0, m, &cVar_hUXH3ocq_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_EXRx7fcY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DxR2qksN, 0, m, &cVar_DxR2qksN_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_NYXWXj27_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hUXH3ocq, 0, m, &cVar_hUXH3ocq_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_nTlrm7PZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NYXWXj27_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EXRx7fcY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_oF4mLzUy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NYXWXj27_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EXRx7fcY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_6fc5ktYR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NYXWXj27_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EXRx7fcY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ANzGNE8V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NYXWXj27_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EXRx7fcY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_RhBo1231_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NYXWXj27_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EXRx7fcY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_suy4RFaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NYXWXj27_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EXRx7fcY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_40f1c7Ql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NYXWXj27_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EXRx7fcY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZlSZI1cY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NYXWXj27_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EXRx7fcY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_OHvtoiql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NYXWXj27_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EXRx7fcY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ijDU9kIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NYXWXj27_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EXRx7fcY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_IEmCV5bP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NYXWXj27_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EXRx7fcY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_ZfbWM0FV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NYXWXj27_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EXRx7fcY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_rX0eTyuB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NYXWXj27_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EXRx7fcY_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_Iwkqe8HD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jSYWnAMy_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Dh3tnP65_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_mVSp9xwA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jSYWnAMy_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Dh3tnP65_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_vyTv0lW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jSYWnAMy_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Dh3tnP65_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_4m4grr14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jSYWnAMy_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Dh3tnP65_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_rI9PsLR7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jSYWnAMy_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Dh3tnP65_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_2vZNJJpa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_FRRCIK43, 0, m, &cVar_FRRCIK43_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_xOMcyDiL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_8AIbEzxt, 0, m, &cVar_8AIbEzxt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vEJahI4V, 0, m, &cVar_vEJahI4V_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2knd23K7, 0, m, &cVar_2knd23K7_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_4jFZFHis_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_NMJz1Xes_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_uAz0IUxW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_NMJz1Xes_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_ERLlSyud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RMDuOn6A, 0, m, &cVar_RMDuOn6A_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_0xI5i4Hs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HIcib3vF, 0, m, &cVar_HIcib3vF_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_wBGTrD78_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1QqZJ2dt, 0, m, &cVar_1QqZJ2dt_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_UxUPbdoO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_NMJz1Xes_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_TyNVIOln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_NMJz1Xes_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_k0TZoDdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jD4pQGwa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_CwzQSC4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jD4pQGwa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_m91c3lEE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4FP6U4iV, 0, m, &cVar_4FP6U4iV_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_TeNrlCo2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_01UEqjl1, 0, m, &cVar_01UEqjl1_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_MmBG3C0q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VV6qcL92, 0, m, &cVar_VV6qcL92_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_X8Ugq0jy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jD4pQGwa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_UDsQHVKv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jD4pQGwa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_c4WFp31l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_2UiQd2F4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_GQSEVbOC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_2UiQd2F4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_Tu41VTSM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gDNwohAn, 0, m, &cVar_gDNwohAn_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_iFceDT25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kkHPw3JI, 0, m, &cVar_kkHPw3JI_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_pPqC1dGy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AtrdkoUE, 0, m, &cVar_AtrdkoUE_sendMessage);
}

void Heavy_WSTD_DL3Y::cMsg_miB9eA3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_2UiQd2F4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cMsg_4SHZoNEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_2UiQd2F4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cBinop_4GGoHLMJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MAYqDEZk, 0, m, &cVar_MAYqDEZk_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Lnd4MYyT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4LRfVWvn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cknzfRSv_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_mnn9tqKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tTZR7Ej3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VFw77w6O_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_tTZR7Ej3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_g7Cymyuj, 1, m, &cIf_g7Cymyuj_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_VFw77w6O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wBptCiL9, 0, m, &cVar_wBptCiL9_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cknzfRSv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MAYqDEZk, 0, m, &cVar_MAYqDEZk_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_4LRfVWvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K61ULp54, 1, m, &cIf_K61ULp54_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_JEibIVtM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_g9M4JmQL, 0, m, &cVar_g9M4JmQL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_Ts4efWgN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cTJjIA9e_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IW2wBduu_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_9Aku98Oh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HrDxHNPm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vDYskLnx_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_HrDxHNPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5hj4MkKl, 1, m, &cIf_5hj4MkKl_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_vDYskLnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bDEEkYjS, 0, m, &cVar_bDEEkYjS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_cTJjIA9e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yQGhBQeR, 1, m, &cIf_yQGhBQeR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_IW2wBduu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_g9M4JmQL, 0, m, &cVar_g9M4JmQL_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_BUfxhUgA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_T36cu6At, 0, m, &cVar_T36cu6At_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_7mcfUPQ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XHV4Y33n_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_paEFvM8e_sendMessage);
}

void Heavy_WSTD_DL3Y::cBinop_oN1pONJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HfWZfaIv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yeSyzAfS_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_yeSyzAfS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zunxaUUd, 0, m, &cVar_zunxaUUd_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_HfWZfaIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dhn8p6XR, 1, m, &cIf_dhn8p6XR_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_XHV4Y33n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_f2np9MJg, 1, m, &cIf_f2np9MJg_sendMessage);
}

void Heavy_WSTD_DL3Y::cCast_paEFvM8e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_T36cu6At, 0, m, &cVar_T36cu6At_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_wL8BaQbS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8AIbEzxt, 0, m, &cVar_8AIbEzxt_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_aBmncDwJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vEJahI4V, 0, m, &cVar_vEJahI4V_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_kwz1v12X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2knd23K7, 0, m, &cVar_2knd23K7_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Cdh4rCMb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SUR3GEK8, 0, m, &cVar_SUR3GEK8_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_RGGFGxrM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P3a1VwnS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9BeMtM1i_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_GpbsIBH0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rQqAXxpe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_k593SX1v_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h9WpkLyb_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_4nf1Da6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WECfqkKA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lIssrBgM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Eu9rbmXl_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_2oSRUFmJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_97evy8FD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RyGPrxOv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yZ89cllc_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_FXXVVSPv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hg3yNHGq_sendMessage(_c, 0, m);
  cMsg_mF68kLsD_sendMessage(_c, 0, m);
  cMsg_trU9TGwk_sendMessage(_c, 0, m);
  cMsg_hxyK3mWD_sendMessage(_c, 0, m);
  cMsg_HGZuVrmJ_sendMessage(_c, 0, m);
  cMsg_OO0Po02C_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_V74cagld, 0, m, &cVar_V74cagld_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SUR3GEK8, 0, m, &cVar_SUR3GEK8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zPPHzmN4, 0, m, &cVar_zPPHzmN4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EBAXsYgY, 0, m, &cVar_EBAXsYgY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wr6KGGeN, 0, m, &cVar_wr6KGGeN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_14VmvNF3, 0, m, &cVar_14VmvNF3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cNPSSeq1, 0, m, &cVar_cNPSSeq1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1p8o5IXl, 0, m, &cVar_1p8o5IXl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_D4JXkojW, 0, m, &cVar_D4JXkojW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IQGe4dU1, 0, m, &cVar_IQGe4dU1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZIH5VoQY, 0, m, &cVar_ZIH5VoQY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OqMqysVy, 0, m, &cVar_OqMqysVy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_F8cbvIgH, 0, m, &cVar_F8cbvIgH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zWjsu0A7, 0, m, &cVar_zWjsu0A7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HFSnbzmu, 0, m, &cVar_HFSnbzmu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CZNMoKGu, 0, m, &cVar_CZNMoKGu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Jrt5pYDn, 0, m, &cVar_Jrt5pYDn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_epNyGda0, 0, m, &cVar_epNyGda0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_S52nkQ35, 0, m, &cVar_S52nkQ35_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BRbGdHJ4, 0, m, &cVar_BRbGdHJ4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VXMoJ0xC, 0, m, &cVar_VXMoJ0xC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_x67ET3YF, 0, m, &cVar_x67ET3YF_sendMessage);
  cMsg_6rpITQY7_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_R75NEsvO, 0, m, &cVar_R75NEsvO_sendMessage);
  cMsg_9Pr4PUKJ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_qINp6PyF, 0, m, &cVar_qINp6PyF_sendMessage);
  cMsg_Na0IshWs_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_uGoxyvne, 0, m, &cVar_uGoxyvne_sendMessage);
  cMsg_kaWdcntb_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_nxrxgwKC, 0, m, &cVar_nxrxgwKC_sendMessage);
  cMsg_dpI2D8GJ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_bs9lxL49, 0, m, &cVar_bs9lxL49_sendMessage);
  cMsg_s3hRY2Zi_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_qYNayVPB, 0, m, &cVar_qYNayVPB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CYGfkcI6, 0, m, &cVar_CYGfkcI6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Od6YCvBB, 0, m, &cVar_Od6YCvBB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NbUU5fxS, 0, m, &cVar_NbUU5fxS_sendMessage);
  cMsg_1JVJjtfz_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_X8IxcfBq, 0, m, &cVar_X8IxcfBq_sendMessage);
  cMsg_hdIbmwMh_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_SiMQL5Q8, 0, m, &cVar_SiMQL5Q8_sendMessage);
  cMsg_mCB3GPB0_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_MYQbQPF5, 0, m, &cVar_MYQbQPF5_sendMessage);
  cMsg_z8D1ZTnW_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_XvztEAth, 0, m, &cVar_XvztEAth_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lYv5QyXa, 0, m, &cVar_lYv5QyXa_sendMessage);
  cMsg_Km9vmlqd_sendMessage(_c, 0, m);
  cMsg_sAMAY7uV_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_QqZgQQo0, 0, m, &cVar_QqZgQQo0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kyzIOww6, 0, m, &cVar_kyzIOww6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_emYzPpJ2, 0, m, &cVar_emYzPpJ2_sendMessage);
  cMsg_DGgZR3cj_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_xUXetBxK, 0, m, &cVar_xUXetBxK_sendMessage);
  cMsg_WaKs7GDG_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_oyIcYOO3, 0, m, &cVar_oyIcYOO3_sendMessage);
  cMsg_KJYI2hjF_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_MdUAbMMH, 0, m, &cVar_MdUAbMMH_sendMessage);
  cMsg_1EEcFj6w_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_to9gHNOr, 0, m, &cVar_to9gHNOr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IovWFZpH, 0, m, &cVar_IovWFZpH_sendMessage);
  cMsg_GCpuCcuM_sendMessage(_c, 0, m);
  cMsg_kiS4g0Cc_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_jBOqt7RQ, 0, m, &cVar_jBOqt7RQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rlxLNri8, 0, m, &cVar_rlxLNri8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2qQrIAiR, 0, m, &cVar_2qQrIAiR_sendMessage);
  cMsg_uuB7BIuS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_jN81pU6p, 0, m, &cVar_jN81pU6p_sendMessage);
  cMsg_Fo0YlVMp_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_AbjLWBiB, 0, m, &cVar_AbjLWBiB_sendMessage);
  cMsg_2b26EeJ7_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_JzFgnREq, 0, m, &cVar_JzFgnREq_sendMessage);
  cMsg_FlUGxX8S_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_5fzM89CI, 0, m, &cVar_5fzM89CI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HcMVUmml, 0, m, &cVar_HcMVUmml_sendMessage);
  cMsg_erxnto1R_sendMessage(_c, 0, m);
  cMsg_aRt3MfKF_sendMessage(_c, 0, m);
  cMsg_xOMcyDiL_sendMessage(_c, 0, m);
  cMsg_2vZNJJpa_sendMessage(_c, 0, m);
  cMsg_PX0yIdqQ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_PI4U6Mmn, 0, m, &cVar_PI4U6Mmn_sendMessage);
  cMsg_TfEs2GA6_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_4x4kdZJU, 0, m, &cTabhead_4x4kdZJU_sendMessage);
  cMsg_xEu4GDwS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_dwJzxV2b, 0, m, &cVar_dwJzxV2b_sendMessage);
  cMsg_Nnxs0Enh_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_5u8fXqna, 0, m, &cTabhead_5u8fXqna_sendMessage);
  cMsg_RJVG7joa_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_014zaDta, 0, m, &cVar_014zaDta_sendMessage);
  cMsg_R1rAXzua_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_OIHZAbFg, 0, m, &cTabhead_OIHZAbFg_sendMessage);
  cMsg_ng0oCCmt_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_WRJ2OwTY, 0, m, &cVar_WRJ2OwTY_sendMessage);
  cMsg_Qcoj6j5c_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_jMesxc8B, 0, m, &cTabhead_jMesxc8B_sendMessage);
  cMsg_FhuyjADM_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_oYKO7Gfk, 0, m, &cVar_oYKO7Gfk_sendMessage);
  cMsg_DTuWoS3J_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_OnklvKOT, 0, m, &cTabhead_OnklvKOT_sendMessage);
  cMsg_8BTo59T0_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_aPZqDUFe, 0, m, &cVar_aPZqDUFe_sendMessage);
  cMsg_1zklYuTZ_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_NgciWd3p, 0, m, &cTabhead_NgciWd3p_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_J8T1cKfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jsy28npv, HV_BINOP_MULTIPLY, 0, m, &cBinop_Jsy28npv_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_lCMKuObd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ZVmChAqJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_e4wB61iG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_2rPvMhTH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_b6GDTicd_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_noE7Wf2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_A6bktJCt_sendMessage);
  cMsg_O5sjIhrE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_TkoW1RA5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IYIFFUkb, HV_BINOP_MULTIPLY, 0, m, &cBinop_IYIFFUkb_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_q0PRY8wv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_TecFGHO6_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_hbsYMy42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wNMvUoqL, HV_BINOP_MULTIPLY, 1, m, &cBinop_wNMvUoqL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_5EeIIud4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_2MscW6fR_sendMessage);
  cMsg_RlUyycl0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_o8Frug87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JLvllVCD, HV_BINOP_MULTIPLY, 0, m, &cBinop_JLvllVCD_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_187foEsP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VE7s46OD_sendMessage(_c, 0, m);
  cMsg_Tqgyo3XQ_sendMessage(_c, 0, m);
  cMsg_kjOxJX2T_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_hkh9LqEK_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_AW26Cqif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_W5s6T5sC_sendMessage);
  cMsg_KIDoWnlp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_WBAhwWI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wr6KGGeN, 0, m, &cVar_wr6KGGeN_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_lcHXCE7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YisjkWbq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R8WDRdUP_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_YHgfewaV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CS0fEL9w_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TDpSIywa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cV1g3bhL_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_5HpT3tlU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FEvctQox_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_r4S6nF9W_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nMeBHQLL_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_wEgMAHNe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dNDPrhkR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nXOmtxOb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aqKxI3Y3_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_YvFhO41Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rXxsQpn1, HV_BINOP_MULTIPLY, 0, m, &cBinop_rXxsQpn1_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_lcrQtmg4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_qNkMfPaf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_yYKnofjO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_WmZ4y0Kr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_skWmWj5G_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_HpxgKr8Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_fsDxUEEy_sendMessage);
  cMsg_pVSLhzCS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_zBfj5idJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zwkYmD3N, HV_BINOP_MULTIPLY, 0, m, &cBinop_zwkYmD3N_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_sJoBkXIP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_dhCFjN1C_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_Q4GA74OE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jlEt08Ff, HV_BINOP_MULTIPLY, 1, m, &cBinop_jlEt08Ff_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_46gvDkPe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_YZNj2Qif_sendMessage);
  cMsg_cm3raErm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_NTIern86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pcMt1H0v, HV_BINOP_MULTIPLY, 0, m, &cBinop_pcMt1H0v_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_M15RNXyW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CbV6nvD3_sendMessage(_c, 0, m);
  cMsg_zQLrXMaW_sendMessage(_c, 0, m);
  cMsg_0BTiaYZs_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_oYgiI53Y_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_5b791AMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_JxTM80mt_sendMessage);
  cMsg_AD58mrMe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DL3Y::cReceive_RYifdDiL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FRRCIK43, 0, m, &cVar_FRRCIK43_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_3SpA0LUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_ERLlSyud_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_TFHE9KiO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_0xI5i4Hs_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_pVzlOulz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_wBGTrD78_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_5vIVKI28_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_m91c3lEE_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_jFVMZOfU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_TeNrlCo2_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_0FSlm4u1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_Tu41VTSM_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_WWFjglF9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_iFceDT25_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_PgIIneDX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_pPqC1dGy_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_R6oqS1PF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_MmBG3C0q_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_OOQXJ5G3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mT4STFHE, HV_BINOP_MULTIPLY, 1, m, &cBinop_mT4STFHE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QkBVAxfX_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qrMbILk8, HV_BINOP_MULTIPLY, 1, m, &cBinop_qrMbILk8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OTXIh3vm_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_JzO02vEi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_F1tZn93S, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_a0YUElSA, m);
}

void Heavy_WSTD_DL3Y::cReceive_LxBaMFtc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Xk3fzRoH_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_7mxGoF1X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_VxGZVIsO_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_duyFzwf1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MvexPnO7, HV_BINOP_MULTIPLY, 1, m, &cBinop_MvexPnO7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OG4C8SbF_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1W7dH990, HV_BINOP_MULTIPLY, 1, m, &cBinop_1W7dH990_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yvhM3vYF_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_r08WcwYK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_QYTkdLuL, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_UNKHeMm7, m);
}

void Heavy_WSTD_DL3Y::cReceive_8W4hhjx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_hGkuJhJu_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_4EGD97Mr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_XEsV3QUF_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_AkCHELWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8nkUUida, HV_BINOP_MULTIPLY, 1, m, &cBinop_8nkUUida_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3LlMwijB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cBaBZXTR, HV_BINOP_MULTIPLY, 1, m, &cBinop_cBaBZXTR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DZxDG6Vq_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_nleWyDXn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_JHCci2hY, m);
  sVarf_onMessage(_c, &Context(_c)->sVarf_SWogqwKA, m);
}

void Heavy_WSTD_DL3Y::cReceive_fWf1QHfQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_AXNauAX3_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_kGJXrN4H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_3OGoGW35_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_3wpYGozh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wBptCiL9, 0, m, &cVar_wBptCiL9_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_ZEPemisj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VvcSrGlx, 0, m, &cVar_VvcSrGlx_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_QckBwmuj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2UWh6rW1, 0, m, &cVar_2UWh6rW1_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_0re5oY55_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bDEEkYjS, 0, m, &cVar_bDEEkYjS_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_5XcrIbSf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zunxaUUd, 0, m, &cVar_zunxaUUd_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_WZy6S8K5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kajGFQeT, 0, m, &cVar_kajGFQeT_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_gs0vypzf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YTznyMpd, 0, m, &cVar_YTznyMpd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0x7IhzAj, 0, m, &cVar_0x7IhzAj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dm86fs1f, 0, m, &cVar_dm86fs1f_sendMessage);
}

void Heavy_WSTD_DL3Y::cReceive_uxZlzIFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JA0lTpzw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_paBvK1km_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_fZ0ELLE4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DL3Y::cReceive_JKMWZMRI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_k6zXXvvi_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DL3Y::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_oAWrsaf7, VOf(Bf0));
    __hv_line_f(&sLine_SaNjLxrq, VOf(Bf1));
    __hv_line_f(&sLine_CuXIByKK, VOf(Bf2));
    __hv_line_f(&sLine_JAleIM1k, VOf(Bf3));
    __hv_line_f(&sLine_0PtToTex, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_T7bck5K6, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_28moRHHy, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_c12qjFl0, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_sqAxfTuM, VOf(Bf1));
    __hv_line_f(&sLine_HA2HptCo, VOf(Bf0));
    __hv_line_f(&sLine_ivvDzFGK, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_58Wadtr3, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_tCJ8XUM2, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_u7CLUdjX, VOf(Bf5));
    __hv_line_f(&sLine_BKv0ZQ84, VOf(Bf1));
    __hv_line_f(&sLine_WIQAcIbv, VOf(Bf2));
    __hv_line_f(&sLine_f1DGJdvU, VOf(Bf4));
    __hv_line_f(&sLine_vJxh4Cvg, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_21P1qFYQ, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_GNj2LvMJ, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_g710SEAi, VOf(Bf6));
    __hv_line_f(&sLine_bcKpJuhl, VOf(Bf2));
    __hv_line_f(&sLine_gUT38zaz, VOf(Bf1));
    __hv_line_f(&sLine_JmRA0MNW, VOf(Bf5));
    __hv_line_f(&sLine_UbTnf1LI, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_j6RX23Dl, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_NWLA7g28, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_oQd2rxIY, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_XtxaQvlg, VOf(Bf2));
    __hv_line_f(&sLine_FPQC4mQQ, VOf(Bf6));
    __hv_line_f(&sLine_5NzbOYOl, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_8fQbPVnY, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_OmqMZ123, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_mpYBqQbF, VOf(Bf8));
    __hv_line_f(&sLine_nNMNxeFp, VOf(Bf2));
    __hv_line_f(&sLine_jkfFCd70, VOf(Bf1));
    __hv_line_f(&sLine_DQSIZ7Ji, VOf(Bf7));
    __hv_line_f(&sLine_Yp8UFEAS, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_45RQ3u4k, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_dhgRowel, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_fPL1nTbV, VOf(Bf9));
    __hv_tabread_f(&sTabread_YTAc1eGi, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_6Q15kY8v, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_kNqIEllm, VOf(Bf9));
    __hv_tabread_f(&sTabread_FXx7x2fI, VOf(Bf8));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_qC2PO2eF, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_MBCoUBC6, VOf(Bf9));
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_C4puBAOZ, VOf(Bf3));
    __hv_rpole_f(&sRPole_yv82bcbO, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_gALBNs36, VIf(Bf3), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_GVUhSYk3, VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_e3nhwujO, VIf(Bf3));
    __hv_varread_f(&sVarf_Df0ol2om, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_47fjI4x8, VOf(Bf5));
    __hv_rpole_f(&sRPole_pZYhOkSJ, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_b0rrKSom, VIf(Bf5), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_BddhWH9f, VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_kSPc10lI, VIf(Bf5));
    __hv_varread_f(&sVarf_F1tZn93S, VOf(Bf5));
    __hv_mul_f(VIf(Bf1), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_n4WfCNIw, VOf(Bf1));
    __hv_varread_f(&sVarf_a0YUElSA, VOf(Bf3));
    __hv_mul_f(VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_Hrp3Pteq, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_7JAhamID, VOf(Bf1));
    __hv_varread_f(&sVarf_x7vQuWH9, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_w8sWCTUd, VOf(Bf1));
    __hv_rpole_f(&sRPole_ldwBviHm, VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_R7KMdNr7, VIf(Bf8), &sEnv_R7KMdNr7_sendMessage);
    __hv_varread_f(&sVarf_SrSRaCdO, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_kxbOVXOL, VOf(Bf1));
    __hv_rpole_f(&sRPole_HmumN3yJ, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_MBCoUBC6, VIf(Bf1));
    __hv_line_f(&sLine_dF9FGcNU, VOf(Bf1));
    __hv_line_f(&sLine_I10cEbaR, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_LqnSAJ94, VOf(Bf1));
    __hv_varread_f(&sVarf_4EdKcnoH, VOf(Bf3));
    __hv_mul_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_vgDHB84c, VOf(Bf1));
    __hv_rpole_f(&sRPole_0OvU1Wya, VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    sEnv_process(this, &sEnv_BPLru1Ws, VIf(Bf8), &sEnv_BPLru1Ws_sendMessage);
    __hv_varread_f(&sVarf_hDJ2Rwln, VOf(Bf8));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_EXVAPhov, VOf(Bf1));
    __hv_rpole_f(&sRPole_WOZV0hAS, VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_Df0ol2om, VIf(Bf1));
    __hv_varwrite_f(&sVarf_eSrzHhFT, VIf(Bf2));
    __hv_varread_f(&sVarf_YazP3TGe, VOf(Bf2));
    __hv_varread_f(&sVarf_RP7zGMtz, VOf(Bf1));
    __hv_line_f(&sLine_S3bp2jJd, VOf(Bf8));
    __hv_tabread_f(&sTabread_HEZUet5I, VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_o0zXKTjv, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf2), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_60cscanS, VOf(Bf8));
    __hv_tabread_f(&sTabread_SSFbyvXA, VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_8iunXTgk, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf1), VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_n3seJudm, VOf(Bf8));
    __hv_add_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_LOlQSmis, VOf(Bf2));
    __hv_rpole_f(&sRPole_mFLodRy0, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_7rAvAq81, VIf(Bf2), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_sub_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_mokwH5ld, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_tabwrite_f(&sTabwrite_ZOw8edq6, VIf(Bf2));
    __hv_varread_f(&sVarf_MxyQS9ed, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_5c6VN4ks, VOf(Bf1));
    __hv_rpole_f(&sRPole_tQfvWWqY, VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_QJQaX2zJ, VIf(Bf1), VOf(Bf8));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_0oHZGur4, VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_le5aNwMb, VIf(Bf1));
    __hv_varread_f(&sVarf_QYTkdLuL, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_LAEdQWtq, VOf(Bf3));
    __hv_varread_f(&sVarf_UNKHeMm7, VOf(Bf2));
    __hv_mul_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_xWgem0k7, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf1), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_5S5vOXMH, VOf(Bf3));
    __hv_varread_f(&sVarf_V3kRjJzs, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_uQztaIh0, VOf(Bf3));
    __hv_rpole_f(&sRPole_TUHuLhvD, VIf(Bf8), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_7C53T0Pd, VIf(Bf9), &sEnv_7C53T0Pd_sendMessage);
    __hv_varread_f(&sVarf_KzbXvgt2, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_9PHF0dZB, VOf(Bf3));
    __hv_rpole_f(&sRPole_k7XoHDGI, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_n3seJudm, VIf(Bf3));
    __hv_line_f(&sLine_7pOtSAQi, VOf(Bf3));
    __hv_line_f(&sLine_tDhPsPIX, VOf(Bf9));
    __hv_mul_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_x1DmdgrR, VOf(Bf3));
    __hv_varread_f(&sVarf_RI08X2CC, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_O0z3mHw6, VOf(Bf3));
    __hv_rpole_f(&sRPole_l00A3EOI, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_DFJIEQRx, VIf(Bf9), &sEnv_DFJIEQRx_sendMessage);
    __hv_varread_f(&sVarf_LK24UNKO, VOf(Bf9));
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_N7UIBDem, VOf(Bf3));
    __hv_rpole_f(&sRPole_fi4rshew, VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_MxyQS9ed, VIf(Bf3));
    __hv_varwrite_f(&sVarf_jsvWv8s5, VIf(Bf5));
    __hv_varread_f(&sVarf_PZEapFMB, VOf(Bf5));
    __hv_varread_f(&sVarf_6GotqVeQ, VOf(Bf3));
    __hv_line_f(&sLine_sjnrv9ru, VOf(Bf9));
    __hv_tabread_f(&sTabread_14kgdxnh, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf8), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_3AjZ855b, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_ZWKg5aZO, VOf(Bf9));
    __hv_tabread_f(&sTabread_dOrlPuKQ, VOf(Bf8));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_KSjAeUBA, VOf(Bf12));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_R5DxSDrV, VOf(Bf9));
    __hv_add_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_CaPtF90q, VOf(Bf5));
    __hv_rpole_f(&sRPole_z2p1vX1N, VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_pPwnCmUE, VIf(Bf5), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_ItvRIWgD, VOf(Bf5));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_O636VV2I, VIf(Bf5));
    __hv_varread_f(&sVarf_OQavpGKp, VOf(Bf5));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_2V1QJf8D, VOf(Bf3));
    __hv_rpole_f(&sRPole_xm2AYPaA, VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_6pO0fgxC, VIf(Bf3), VOf(Bf9));
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_XWmMfFw8, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_No5W9kPu, VIf(Bf3));
    __hv_varread_f(&sVarf_JHCci2hY, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_P8N7HRta, VOf(Bf2));
    __hv_varread_f(&sVarf_SWogqwKA, VOf(Bf5));
    __hv_mul_f(VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_Ajm2fVNm, VOf(Bf8));
    __hv_mul_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf3), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_2FELjDFx, VOf(Bf2));
    __hv_varread_f(&sVarf_iKvg9tEB, VOf(Bf9));
    __hv_mul_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_D08FwTfS, VOf(Bf2));
    __hv_rpole_f(&sRPole_3PWyyig8, VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_Gm5Etzfd, VIf(Bf8), &sEnv_Gm5Etzfd_sendMessage);
    __hv_varread_f(&sVarf_cXKK7fEd, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_ea4D5TlJ, VOf(Bf2));
    __hv_rpole_f(&sRPole_i4QSOT7t, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_R5DxSDrV, VIf(Bf2));
    __hv_line_f(&sLine_zo6ZxP0q, VOf(Bf2));
    __hv_line_f(&sLine_IasK3k7S, VOf(Bf8));
    __hv_mul_f(VIf(Bf3), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_HpeargDJ, VOf(Bf2));
    __hv_varread_f(&sVarf_9YTKvYQ5, VOf(Bf5));
    __hv_mul_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_09yBpt3P, VOf(Bf2));
    __hv_rpole_f(&sRPole_yQqRs6qj, VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_LcphiCwq, VIf(Bf8), &sEnv_LcphiCwq_sendMessage);
    __hv_varread_f(&sVarf_tHwzBFle, VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_ygmG6B2l, VOf(Bf2));
    __hv_rpole_f(&sRPole_W2TrxtEi, VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_OQavpGKp, VIf(Bf2));
    __hv_varwrite_f(&sVarf_ZvmOlluh, VIf(Bf1));
    __hv_varwrite_f(&sVarf_5CisSy1j, VIf(Bf10));
    __hv_varwrite_f(&sVarf_GS0GaIf5, VIf(Bf11));
    __hv_varwrite_f(&sVarf_nDteYBCD, VIf(Bf12));
    __hv_varwrite_f(&sVarf_YazP3TGe, VIf(Bf0));
    __hv_varwrite_f(&sVarf_RP7zGMtz, VIf(Bf6));
    __hv_varwrite_f(&sVarf_PZEapFMB, VIf(Bf4));
    __hv_varwrite_f(&sVarf_6GotqVeQ, VIf(Bf7));
    __hv_varread_f(&sVarf_5CisSy1j, VOf(Bf7));
    __hv_varread_f(&sVarf_GS0GaIf5, VOf(Bf4));
    __hv_varread_f(&sVarf_nDteYBCD, VOf(Bf6));
    __hv_add_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_eSrzHhFT, VOf(Bf6));
    __hv_varread_f(&sVarf_jsvWv8s5, VOf(Bf7));
    __hv_varread_f(&sVarf_ZvmOlluh, VOf(Bf4));
    __hv_add_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf4), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DL3Y::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DL3Y::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
